@@ -1,23 +1,8 @@
-/*
- * Copyright (C) 2021 ~ 2021 Uniontech Technology Co., Ltd.
- *
- * Author:     Chen Bin <chenbin@uniontech.com>
- *
- * Maintainer: Chen Bin <chenbin@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2021 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
+
 #include "daccessibilitychecker.h"
 
 #include <DObjectPrivate>
@@ -457,9 +442,9 @@ void DAccessibilityChecker::setOutputFormat(DAccessibilityChecker::OutputFormat
 
    \brief 日志格式枚举.
 
-   \value AssertFormat
+   \var AssertFormat
    断言日志，如检查到缺失，直接断言。
-   \value FullFormat
+   \var FullFormat
    全日志，全日志将所有的缺失信息显示到控制台中。
    \sa DAccessibilityChecker::outputFormat
  */
@@ -470,9 +455,9 @@ void DAccessibilityChecker::setOutputFormat(DAccessibilityChecker::OutputFormat
   \brief 检测的角色.
 
   检测角色目前分为两种。
-  \value Widget
+  \var Widget
   所有继承自 QWidget 的小控件
-  \value ViewItem
+  \var ViewItem
   所有继承自 QStandardItem 的View Item项
  */
 
