@@ -1,31 +1,23 @@
-/*
- * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "darrowrectangle.h"
 #include "dplatformwindowhandle.h"
 #include "dapplication.h"
 #include "private/darrowrectangle_p.h"
+#include "dgraphicsgloweffect.h"
 #include "dstyle.h"
 
 #include <DGuiApplicationHelper>
-
+#include<qpa/qplatformnativeinterface.h>
 #ifdef Q_OS_LINUX
 #include <X11/extensions/shape.h>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QX11Info>
+#else
+#include <QtGui/private/qtx11extras_p.h>
+#endif
 #endif
 #include <QApplication>
 #include <QScreen>
@@ -33,14 +25,17 @@
 
 DWIDGET_BEGIN_NAMESPACE
 
+static bool isDwayland()
+{
+    return qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool();
+}
 /*!
-  \class Dtk::Widget::DArrowRectangle
-  \inmodule dtkwidget
-  \brief DArrowRectangle 提供了可以在四个边中的任意一个边显示箭头的矩形控件.
-  \brief The DArrowRectangle class provides a widget that has an arrow on one
+@~english
+  @class Dtk::Widget::DArrowRectangle
+  @ingroup dtkwidget
+  @brief The DArrowRectangle class provides a widget that has an arrow on one
   of its four borders.
 
-  通常用于作为其他控件的容器，将其显示在矩形内作为内容控件
   It's usually used as a container of some other widgets,
   see DArrowRectangle::setContent()
 
@@ -48,49 +43,45 @@ DWIDGET_BEGIN_NAMESPACE
  */
 
 /*!
-  \enum Dtk::Widget::DArrowRectangle::ArrowDirection
-  \brief 箭头方向枚举包含 DArrowRectangle 的箭头可能指向的可能方向.
-  \brief The ArrowDirection enum contains the possible directions that
+@~english
+  @enum Dtk::Widget::DArrowRectangle::ArrowDirection
+  @brief The ArrowDirection enum contains the possible directions that
   the DArrowRectangle's arrow may point to.
 
   \value ArrowLeft
-  指示此矩形的箭头将指向左侧
   indicates the arrow of this rectangle will point left
   \value ArrowRight
-  指示此矩形的箭头将指向右侧
   indicates the arrow of this rectangle will point right
   \value ArrowTop
-  指示此矩形的箭头将指向上方
   indicates the arrow of this rectangle will point up
   \value ArrowBottom
-  指示此矩形的箭头将向下指向
   indicates the arrow of this rectangle will point down
  */
 
 /*!
-  \enum Dtk::Widget::DArrowRectangle::FloatMode
-  \brief FloatMode 表示不同的控件的浮动模式
-  \brief The FloatMode enum decide the WindowType when DArrowRectangle show
-  
-  控件的浮动模式表示控件如何显示在布局中，DArrowRectangle::FloatWindow 表示控件将会以一个单独的窗口显示，而 DArrowRectangle::FloatWidget 则表示控件只能显示在其父控件的布局中，不能超出父控件大小
+@~english
+  @enum Dtk::Widget::DArrowRectangle::FloatMode
+  @brief The FloatMode enum decide the WindowType when DArrowRectangle show
   
+  The floating mode of the control indicates how the control is displayed in the layout. 
+  DArrowRectangle::FloatWindow indicates that the control will be displayed as a separate window, 
+  while DArrowRectangle::FloatWidget indicates that the control can only be displayed in the layout of its parent control and cannot exceed the size of the parent control.
+
   \value FloatWindow
-  窗口模式
+  Window mode
   Window will show a separate window
   \value FloatWidget
-  控件模式
+  Widget mode
   Widget must by show in the rect of parentWidget
  */
 
 /*!
-  \brief DArrowRectangle::DArrowRectangle constructs an instance of DArrowRectangle.
-  \brief 获取 DArrowRectangle 实例
+@~english
+  @brief DArrowRectangle::DArrowRectangle constructs an instance of DArrowRectangle.
 
   \a direction is used to initialize the direction of which the arrow
   points to.
   \a parent is the parent widget the arrow rectangle will be attached to.
-  \a direction 用于初始化箭头的方向
-  \a parent 作为其父控件
  */
 DArrowRectangle::DArrowRectangle(ArrowDirection direction, QWidget *parent) :
     QWidget(parent),
@@ -102,14 +93,15 @@ DArrowRectangle::DArrowRectangle(ArrowDirection direction, QWidget *parent) :
 }
 
 /*!
-  \brief 获取 DArrowRectangle 实例，并指定浮动模式.
-  \brief DArrowRectangle::DArrowRectangle can set DArrowRectangle show as a window or
+@~english
+  @brief get the DArrowRectangle instance and specify the floating mode.
+  @brief DArrowRectangle::DArrowRectangle can set DArrowRectangle show as a window or
   a widget in parentWidget by floatMode
 
-  \a direction 用于初始化箭头的方向
-  \a floatMode
-  \a parent 作为其父控件
-  \sa DArrowRectangle::FloatMode
+  \a direction Used to initialize the direction of the arrow
+  \a floatMode 
+  \a parent as its parent control
+  @sa DArrowRectangle::FloatMode
  */
 DArrowRectangle::DArrowRectangle(ArrowDirection direction, FloatMode floatMode, QWidget *parent) :
     QWidget(parent),
@@ -121,15 +113,12 @@ DArrowRectangle::DArrowRectangle(ArrowDirection direction, FloatMode floatMode,
 }
 
 /*!
-  \brief 在指定的坐标位置显示本控件；
-  \brief DArrowRectangle::show shows the widget at the given coordinate.
+@~english
+  @brief DArrowRectangle::show shows the widget at the given coordinate.
   
-  \note 坐标被计算为箭头的位置，所以你不需要自己计算箭头位置
-  \note The coordiate is calculated to be the arrow head's position, so you
+  @note The coordiate is calculated to be the arrow head's position, so you
   don't need to calculate the position yourself.
-  
-  \a x 控件箭头的x轴坐标
-  \a y 控件箭头的y轴坐标
+
   \a x is the x coordinate of the arrow head.
   \a y is the y coordinate of the arrow head.
  */
@@ -141,10 +130,10 @@ void DArrowRectangle::show(int x, int y)
 }
 
 /*!
-  \brief DArrowRectangle::setContent sets the content of the arrow rectangle.
-  \brief 设置要显示在矩形内的内容控件.
+@~english
+  @brief DArrowRectangle::setContent sets the content of the arrow rectangle.
 
-  \a content 要显示内容控件
+  \a content to display a content control
  */
 void DArrowRectangle::setContent(QWidget *content)
 {
@@ -154,9 +143,10 @@ void DArrowRectangle::setContent(QWidget *content)
 }
 
 /*!
-  \brief 获取内容控件.
+@~english
+  @brief get content control.
 
-  \return 正在显示的内容控件
+  \return the content control being displayed
  */
 QWidget *DArrowRectangle::getContent() const
 {
@@ -166,8 +156,8 @@ QWidget *DArrowRectangle::getContent() const
 }
 
 /*!
-  \brief 根据内容控件的大小自动设置矩形控件的大小.
-  \brief DArrowRectangle::resizeWithContent automatically adjust the rectangle's
+@~english
+  @brief DArrowRectangle::resizeWithContent automatically adjust the rectangle's
   size to fit the its content.
  */
 void DArrowRectangle::resizeWithContent()
@@ -178,10 +168,10 @@ void DArrowRectangle::resizeWithContent()
 }
 
 /*!
-  \brief 获取整个矩形控件的大小.
-  \brief DArrowRectangle::getFixedSize.
+@~english
+  @brief gets the size of the entire rectangular control.
+  @brief DArrowRectangle::getFixedSize.
 
-  \return 矩形控件的大小
   \return the size of the whole widget.
  */
 QSize DArrowRectangle::getFixedSize()
@@ -207,15 +197,12 @@ QSize DArrowRectangle::getFixedSize()
 }
 
 /*!
-  \brief 移动到指定的坐标位置.
-  \brief DArrowRectangle::move moves the widget to the coordinate that provided,
+@~english
+  @brief DArrowRectangle::move moves the widget to the coordinate that provided,
   
-  参数的作用类似于 DArrowRectangle::show , 移动整个控件直到箭头出现在参数中指定的坐标
   Like the rules in DArrowRectangle::show(int x, int y), it moves the widget so
   that the arrow head's coordinate matches the one that provided.
   
-  \a x 控件箭头的x轴坐标
-  \a y 控件箭头的y轴坐标
   \a x is the x coordinate of the arrow head.
   \a y is the y coordinate of the arrow head.
 
@@ -274,6 +261,13 @@ bool DArrowRectangle::event(QEvent *e)
 
 const QRect DArrowRectanglePrivate::currentScreenRect(const int x, const int y)
 {
+    if (floatMode == DArrowRectangle::FloatWidget) {
+        D_Q(DArrowRectangle);
+        if (q->windowType() == Qt::Widget && q->parentWidget()) {
+            return q->parentWidget()->rect();
+        }
+    }
+
     for (QScreen *screen : qApp->screens())
         if (screen->geometry().contains(x, y)) {
             return screen->geometry();
@@ -283,11 +277,10 @@ const QRect DArrowRectanglePrivate::currentScreenRect(const int x, const int y)
 }
 
 /*!
-  \property DArrowRectangle::shadowYOffset
-  \property DArrowRectangle::shadowYOffset
+@~english
+  @property DArrowRectangle::shadowYOffset
 
-  \brief 这属性表示小部件及其阴影在y轴上的偏移量.
-  \brief the offset of the widget and its shadow on y axis.
+  @brief the offset of the widget and its shadow on y axis.
 
   Getter: DArrowRectangle::shadowYOffset Setter: DArrowRectangle::setShadowYOffset
   \sa DArrowRectangle::shadowXOffset
@@ -311,9 +304,10 @@ void DArrowRectangle::setShadowYOffset(const qreal &shadowYOffset)
 }
 
 /*!
-  \brief DArrowRectangle::setLeftRightRadius 设置左右箭头时的圆角.
+@~english
+  @brief DArrowRectangle::setLeftRightRadius fillet when setting the left and right arrows.
 
-  \a enable 是否开启.
+  \a enable Whether to open.
  */
 void DArrowRectangle::setLeftRightRadius(bool enable)
 {
@@ -322,9 +316,10 @@ void DArrowRectangle::setLeftRightRadius(bool enable)
 }
 
 /*!
-  \brief DArrowRectangle::setArrowStyleEnable 设置圆角箭头样式.
+@~english
+  @brief DArrowRectangle::setArrowStyleEnable Set Rounded Arrow Style.
 
-  \a enable 是否开启.
+  \a enable Whether to open.
  */
 void DArrowRectangle::setRadiusArrowStyleEnable(bool enable)
 {
@@ -335,10 +330,22 @@ void DArrowRectangle::setRadiusArrowStyleEnable(bool enable)
 }
 
 /*!
-  \property DArrowRectangle::shadowXOffset
+@~english
+  @brief DArrowRectangle::setRadiusForceEnable Set fillet style.
+  @brief By default, the window tube supports the fillet when the special effect is mixed, 
+  and there is no fillet when there is no special effect. If it is enabled, there is always a fillet
+  \a enable Whether to open.
+ */
+void DArrowRectangle::setRadiusForceEnable(bool enable)
+{
+    setProperty("_d_radius_force", enable);
+}
 
-  \brief 这属性表示小部件及其阴影在x轴上的偏移量
-  \brief the offset of the widget and its shadow on x axis.
+/*!
+@~english
+  @property DArrowRectangle::shadowXOffset
+
+  @brief the offset of the widget and its shadow on x axis.
   
   Getter: DArrowRectangle::shadowXOffset Setter: DArrowRectangle::setShadowXOffset
   \sa DArrowRectangle::shadowYOffset
@@ -362,10 +369,10 @@ void DArrowRectangle::setShadowXOffset(const qreal &shadowXOffset)
 }
 
 /*!
-  \property DArrowRectangle::shadowBlurRadius
+@~english
+  @property DArrowRectangle::shadowBlurRadius
 
-  \brief 这个属性保存小部件阴影的模糊半径
-  \brief This property holds the blur radius of the widget's shadow.
+  @brief This property holds the blur radius of the widget's shadow.
   
   Getter: DArrowRectangle::shadowBlurRadius Setter: DArrowRectangle::setShadowBlurRadius
  */
@@ -388,10 +395,10 @@ void DArrowRectangle::setShadowBlurRadius(const qreal &shadowBlurRadius)
 }
 
 /*!
-  \property DArrowRectangle::borderColor
+@~english
+  @property DArrowRectangle::borderColor
 
-  \brief 这个属性表示控件边框的颜色
-  \brief This property holds the border color of this widget.
+  @brief This property holds the border color of this widget.
   
   Getter: DArrowRectangle::borderColor , Setter: DArrowRectangle::setBorderColor
  */
@@ -414,10 +421,10 @@ void DArrowRectangle::setBorderColor(const QColor &borderColor)
 }
 
 /*!
-  \property DArrowRectangle::borderWidth
+@~english
+  @property DArrowRectangle::borderWidth
 
-  \brief 这个属性表示控件边框的宽度
-  \brief This property holds the border width of this widget.
+  @brief This property holds the border width of this widget.
   
   Getter: DArrowRectangle::borderWidth , Setter: DArrowRectangle::setBorderWidth
  */
@@ -440,10 +447,10 @@ void DArrowRectangle::setBorderWidth(int borderWidth)
 }
 
 /*!
-  \property DArrowRectangle::backgroundColor
+@~english
+  @property DArrowRectangle::backgroundColor
 
-  \brief 这个属性表示矩形控件的背景颜色
-  \brief the background color of this rectangle.
+  @brief the background color of this rectangle.
   
   Getter: DArrowRectangle::backgroundColor , Setter: DArrowRectangle::setBackgroundColor
  */
@@ -455,10 +462,10 @@ QColor DArrowRectangle::backgroundColor() const
 }
 
 /*!
-  \property DArrowRectangle::arrowDirection
+@~english
+  @property DArrowRectangle::arrowDirection
 
-  \brief This property holds the direction of the rectangle's arrow points to.
-  \brief 这个属性表示箭头的方向
+  @brief This property holds the direction of the rectangle's arrow points to.
   
   Getter: DArrowRectangle::arrowDirection , Setter: DArrowRectangle::setArrowDirection
  */
@@ -475,7 +482,8 @@ void DArrowRectangle::setBackgroundColor(const QColor &backgroundColor)
 
     d->m_backgroundColor = backgroundColor;
 
-    if (d->m_handle && d->m_backgroundColor.toRgb().alpha() < 255) {
+    bool isFloatWindow = d->floatMode == FloatWindow;
+    if ((d->m_handle || (isFloatWindow && isDwayland())) && d->m_backgroundColor.toRgb().alpha() < 255) {
         if (!d->m_blurBackground) {
             d->m_blurBackground = new DBlurEffectWidget(this);
             d->m_blurBackground->setBlendMode(DBlurEffectWidget::BehindWindowBlend);
@@ -496,10 +504,9 @@ void DArrowRectangle::setBackgroundColor(const QColor &backgroundColor)
 }
 
 /*!
-  \brief DArrowRectangle::setBackgroundColor is an overloaded function.
-  \brief DArrowRectangle::setBackgroundColor 是一个重载方法
+@~english
+  @brief DArrowRectangle::setBackgroundColor is an overloaded function.
   
-  通过改变 DBlurEffectWidget::MaskColorType 来修改控件矩形的背景
   It sets the background color by modifing the mask color of the
   Dtk::Widget::DBlurEffectWidget.
 
@@ -516,10 +523,10 @@ void DArrowRectangle::setBackgroundColor(DBlurEffectWidget::MaskColorType type)
 }
 
 /*!
-  \property DArrowRectangle::radius
+@~english
+  @property DArrowRectangle::radius
 
-  \brief 这个属性表示矩形的圆角
-  \brief radius of the rectangle
+  @brief radius of the rectangle
   
   Getter: DArrowRectangle::radius , Setter: DArrowRectangle::setRadius
  */
@@ -531,10 +538,23 @@ int DArrowRectangle::radius() const
 }
 
 /*!
-  \property DArrowRectangle::arrowHeight
+@~english
+  @property DArrowRectangle::radiusForceEnabled
 
-  \brief height of rectangle's arrow
-  \brief 这个属性表示箭头的高度
+  @brief Whether to force (Ignore special effects) open the fillet
+
+  Getter: DArrowRectangle::radiusForceEnabled , Setter: DArrowRectangle::setRadiusForceEnable
+ */
+bool DArrowRectangle::radiusForceEnabled() const
+{
+    return property("_d_radius_force").toBool();
+}
+
+/*!
+@~english
+  @property DArrowRectangle::arrowHeight
+
+  @brief height of rectangle's arrow
   
   Getter: DArrowRectangle::arrowHeight , Setter: DArrowRectangle::setArrowHeight
   \sa DArrowRectangle::arrowWidth
@@ -547,10 +567,10 @@ int DArrowRectangle::arrowHeight() const
 }
 
 /*!
-  \property DArrowRectangle::arrowWidth
+@~english
+  @property DArrowRectangle::arrowWidth
 
-  \brief 这个属性表示箭头的宽度
-  \brief width of the rectangle's arrow
+  @brief width of the rectangle's arrow
   
   Getter: DArrowRectangle::arrowWidth , Setter: DArrowRectangle::setArrowWidth
   \sa DArrowRectangle::arrowHeight
@@ -563,10 +583,10 @@ int DArrowRectangle::arrowWidth() const
 }
 
 /*!
-  \property DArrowRectangle::arrowX
+@~english
+  @property DArrowRectangle::arrowX
 
-  \brief the x coordinate of the rectangle's arrow
-  \brief 这个属性表示箭头的x轴坐标
+  @brief the x coordinate of the rectangle's arrow
   
   Getter: DArrowRectangle::arrowX , Setter: DArrowRectangle::setArrowX
   \sa DArrowRectangle::arrowY
@@ -579,10 +599,10 @@ int DArrowRectangle::arrowX() const
 }
 
 /*!
-  \property DArrowRectangle::arrowY
+@~english
+  @property DArrowRectangle::arrowY
 
-  \brief 这个属性表示箭头的y轴坐标
-  \brief the y coordinate of the rectangle's arrow
+  @brief the y coordinate of the rectangle's arrow
   
   Getter: DArrowRectangle::arrowY , Setter: DArrowRectangle::setArrowY
   \sa DArrowRectangle::arrowX
@@ -595,15 +615,14 @@ int DArrowRectangle::arrowY() const
 }
 
 /*!
-  \property DArrowRectangle::margin
+@~english
+  @property DArrowRectangle::margin
 
-  \brief 这个属性表示边距大小
-  \brief This property holds the width of the margin
+  @brief This property holds the width of the margin
   
   The margin is the distance between the innermost pixel of the rectangle and the
   outermost pixel of its contents.
   The default margin is 0.
-  边距是指矩形最里面的像素与其内容最外面的像素之间的距离
   Getter: DArrowRectangle::margin , Setter: DArrowRectangle::setMargin
 
   \sa DArrowRectangle::setMargin
@@ -616,9 +635,10 @@ int DArrowRectangle::margin() const
 }
 
 /*!
-  \brief 该函数用于设置箭头方向.
+@~english
+  @brief this function is used to set the arrow direction.
 
-  \a value 箭头方向.
+  \a value arrow direction.
 
   \sa DArrowRectangle::arrowDirection
  */
@@ -630,9 +650,10 @@ void DArrowRectangle::setArrowDirection(ArrowDirection value)
 }
 
 /*!
-  \brief 该函数用于设置整个控件固定的宽度
+@~english
+  @brief This function is used to set the fixed width of the entire control
   
-  \a value 宽度大小
+  \a value width Size
  */
 void DArrowRectangle::setWidth(int value)
 {
@@ -640,9 +661,10 @@ void DArrowRectangle::setWidth(int value)
 }
 
 /*!
-  \brief 设置整个控件固定的高度
+@~english
+  @brief set the fixed height of the entire control
   
-  \a value 高度大小
+  \a value height Size
  */
 void DArrowRectangle::setHeight(int value)
 {
@@ -650,9 +672,10 @@ void DArrowRectangle::setHeight(int value)
 }
 
 /*!
-  \brief 该函数用于设置圆角大小.
+@~english
+  @brief this function is used to set the fillet size.
 
-  \a value 圆角大小.
+  \a value fillet size.
 
   \sa DArrowRectangle::radius
  */
@@ -664,9 +687,10 @@ void DArrowRectangle::setRadius(int value)
 }
 
 /*!
-  \brief 设置箭头高度.
+@~english
+  @brief set arrow height.
 
-  \a value 箭头高度.
+  \a value arrow Height.
 
   \sa DArrowRectangle::arrowHeight
  */
@@ -678,9 +702,10 @@ void DArrowRectangle::setArrowHeight(int value)
 }
 
 /*!
-  \brief 设置箭头宽度.
+@~english
+  @brief set arrow width.
 
-  \a value 箭头宽度.
+  \a value arrow width.
 
   \sa DArrowRectangle::arrowWidth
  */
@@ -692,9 +717,10 @@ void DArrowRectangle::setArrowWidth(int value)
 }
 
 /*!
-  \brief 设置箭头 x 坐标的值.
+@~english
+  @brief set the value of the arrow x coordinate.
 
-  \a value x 坐标的值.
+  \a value x value of coordinates.
 
   \sa DArrowRectangle::arrowX
  */
@@ -706,9 +732,10 @@ void DArrowRectangle::setArrowX(int value)
 }
 
 /*!
-  \brief 设置箭头 y 坐标的值.
+@~english
+  @brief set the value of arrow y coordinate.
 
-  \a value y 坐标的值.
+  \a value y value of coordinates.
 
   \sa DArrowRectangle::arrowY
  */
@@ -720,9 +747,10 @@ void DArrowRectangle::setArrowY(int value)
 }
 
 /*!
-  \brief 设置边距大小.
+@~english
+  @brief set margin size.
 
-  \a value 边距大小.
+  \a value margin size.
 
   \sa DArrowRectangle::margin
  */
@@ -773,7 +801,7 @@ QPainterPath DArrowRectanglePrivate::getLeftCornerPath()
     border.arcTo(bottomRight.x() - 2 * radius, bottomRight.y() - 2 * radius, 2 * radius, 2 * radius, 0, -90);
 
     if (radiusArrowStyleEnable) {
-        border.lineTo(bottomLeft.x() + arrowWidth, bottomLeft.y());
+        border.lineTo(bottomLeft.x() + radius, bottomLeft.y());
         border.arcTo(bottomLeft.x(), bottomLeft.y() - widgetRadius, widgetRadius, widgetRadius, -90, -90);
         border.lineTo(bottomLeft.x(), cornerPoint.y() + m_arrowWidth / 2 + radius / 2);
 
@@ -791,9 +819,11 @@ QPainterPath DArrowRectanglePrivate::getLeftCornerPath()
 
         border.lineTo(topLeft.x(), cornerPoint.y() - m_arrowWidth / 2 - radius / 2);
         border.arcTo(topLeft.x(), topLeft.y(), widgetRadius, widgetRadius, -180, -90);
+
+        border.lineTo(topLeft.x() + radius, topLeft.y());
     } else {
         if (leftRightRadius) {
-            border.lineTo(bottomLeft.x() + arrowWidth, bottomLeft.y());
+            border.lineTo(bottomLeft.x() + radius, bottomLeft.y());
             border.arcTo(bottomLeft.x(), bottomLeft.y() - widgetRadius, widgetRadius, widgetRadius, -90, -90);
             border.lineTo(bottomLeft.x(), cornerPoint.y() + m_arrowWidth / 2);
         } else {
@@ -873,6 +903,8 @@ QPainterPath DArrowRectanglePrivate::getRightCornerPath()
 
         border.lineTo(bottomRight.x(), cornerPoint.y() + m_arrowWidth / 2 + radius / 2);
         border.arcTo(bottomRight.x() - widgetRadius, bottomRight.y() - widgetRadius, widgetRadius, widgetRadius, 0, -90);
+
+        border.lineTo(bottomRight.x() - radius, bottomRight.y());
     } else {
         if (leftRightRadius) {
             border.lineTo(topRight.x() - radius, topRight.y());
@@ -1112,6 +1144,9 @@ void DArrowRectanglePrivate::updateClipPath()
 {
     D_Q(DArrowRectangle);
 
+    if (!isDwayland() && !m_handle)
+        return;
+
     QPainterPath path;
 
     switch (m_arrowDirection) {
@@ -1133,7 +1168,7 @@ void DArrowRectanglePrivate::updateClipPath()
 
     if (m_handle) {
         m_handle->setClipPath(path);
-    } else {
+    } else if (DArrowRectangle::FloatWindow == floatMode && isDwayland()) {
         // clipPath without handle
         QPainterPathStroker stroker;
         stroker.setCapStyle(Qt::RoundCap);
@@ -1144,13 +1179,16 @@ void DArrowRectanglePrivate::updateClipPath()
 
         q->clearMask();
         q->setMask(polygon);
+        if (m_blurBackground)
+            m_blurBackground->setMaskPath(path);
 
         if (QWidget *widget = q->window()) {
             if (QWindow *w = widget->windowHandle()) {
                 QList<QPainterPath> painterPaths;
                 painterPaths << outPath.united(path);
-                DPlatformHandle handle(w);
-                handle.setWindowBlurAreaByWM(painterPaths);
+                // 背景模糊也要设置一个 path
+                qApp->platformNativeInterface()->setWindowProperty(w->handle(), "_d_windowBlurPaths",
+                                                                   QVariant::fromValue(painterPaths));
             }
         }
     }
@@ -1159,7 +1197,7 @@ void DArrowRectanglePrivate::updateClipPath()
 bool DArrowRectanglePrivate::radiusEnabled()
 {
     D_Q(DArrowRectangle);
-    if (q->property("_d_radius_force").toBool())
+    if (q->radiusForceEnabled())
         return true;
 
     if (m_wmHelper && !m_wmHelper->hasComposite()) {
@@ -1217,8 +1255,17 @@ void DArrowRectanglePrivate::init(DArrowRectangle::FloatMode mode)
             q->update();
             this->updateClipPath();
         }, Qt::QueuedConnection);
+    } else if (DArrowRectangle::FloatWidget == floatMode) {
+        DGraphicsGlowEffect *glowEffect = new DGraphicsGlowEffect;
+        glowEffect->setBlurRadius(q->shadowBlurRadius());
+        glowEffect->setDistance(m_shadowDistance);
+        glowEffect->setXOffset(q->shadowXOffset());
+        glowEffect->setYOffset(q->shadowYOffset());
+        q->setGraphicsEffect(glowEffect);
     } else {
-        m_wmHelper = nullptr;
+#ifndef QT_DEBUG
+        qDebug() << "wayland:" << isDwayland() << "floatMode:" << floatMode;
+#endif
     }
 }
 
@@ -1328,7 +1375,7 @@ void DArrowRectanglePrivate::paintEvent(QPaintEvent *e)
     QColor bk_color;
 
     if (!m_backgroundColor.isValid()) {
-        bk_color = qApp->palette().background().color();
+        bk_color = qApp->palette().window().color();
     } else {
         bk_color = m_backgroundColor;
     }
