@@ -1,27 +1,12 @@
-/*
- * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
- *
- * Author:     zccrs <zccrs@live.com>
- *
- * Maintainer: zccrs <zhangjide@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "dcrumbedit.h"
 #include "dobject_p.h"
 #include "DStyle"
-
+#include "dsizemode.h"
+#include <QRandomGenerator>
 #include <QAbstractTextDocumentLayout>
 #include <QPainter>
 #include <QPainterPath>
@@ -34,6 +19,8 @@
 #include <QJsonArray>
 #include <QTime>
 
+#include <private/qtextdocument_p.h>
+
 DWIDGET_BEGIN_NAMESPACE
 
 enum Background {
@@ -125,12 +112,36 @@ public:
     QBrush backgroundBrush(const QRect &rect, const QBrush &brush);
 };
 
+class DCrumbEditPanelFrame : public QWidget {
+    Q_OBJECT
+
+public:
+    explicit DCrumbEditPanelFrame(QWidget *parent = nullptr)
+        :QWidget(parent)
+    {
+        setFocusProxy(parent);
+    }
+
+protected:
+    void paintEvent(QPaintEvent *event) override;
+};
+
+void DCrumbEditPanelFrame::paintEvent(QPaintEvent *event)
+{
+    QPainter p(this);
+    QStyleOptionFrame panel;
+    panel.initFrom(parentWidget());
+    panel.rect = rect();
+    style()->drawPrimitive(QStyle::PE_PanelLineEdit, &panel, &p, parentWidget());
+    QWidget::paintEvent(event);
+}
+
 /*!
-    \class Dtk::Widget::DCrumbTextFormat
+@~english
+    @class Dtk::Widget::DCrumbTextFormat
     \inmodule dtkwidget
 
-    \brief 表示标签输入控件所含标签的文字样式.
-    \brief Text format for Tags/Crumbs inside DCrumbEdit.
+    @brief Text format for Tags/Crumbs inside DCrumbEdit.
 
     DCrumbTextFormat comes with properties to indicate the look of a tag/crumb inside a DCrumbEdit.
 
@@ -140,12 +151,8 @@ public:
     Using DCrumbEdit::makeTextFormat() to create a DCrumbTextFormat object is always recommended,
     if you are going to craft your own DCrumbTextFormat object, don't forget to call the
     DCrumbTextFormat::setObjectType function(normally value should be `QTextFormat::UserObject + 1`).
-    DCrumbTextFormat 包含了表示标签输入控件 DCrumbEdit 内所包含的标签的各种样式属性。
-    文字属性为标识一个标签的唯一重要属性，其他可用的属性包含标签背景颜色，标签文字颜色以及标签圆角程度等可供使用。
-    总是建议通过 DCrumbEdit::makeTextFormat() 来构造一个可供使用的 DCrumbTextFormat 对象，若希望自行构造，
-    请留意使用 DCrumbTextFormat::setObjectType 来设置必要的对象类型 (通常应为 `QTextFormat::UserObject + 1`).
 
-    \sa DCrumbEdit
+    @sa DCrumbEdit
 */
 
 DCrumbTextFormat::DCrumbTextFormat()
@@ -155,8 +162,9 @@ DCrumbTextFormat::DCrumbTextFormat()
 }
 
 /*!
-  \brief DCrumbTextFormat::tagColor
-  \return 返回标签的颜色
+@~english
+  @brief DCrumbTextFormat::tagColor return the color of the tag/crumb
+  @return the color of the tag/crumb
  */
 QColor DCrumbTextFormat::tagColor() const
 {
@@ -164,8 +172,9 @@ QColor DCrumbTextFormat::tagColor() const
 }
 
 /*!
-  \brief DCrumbTextFormat::setTagColor 设置标签颜色
-  \a color 标签的颜色
+@~english
+  @brief DCrumbTextFormat::setTagColor set the color of the tag/crumb
+  @param[in] color color of the tag/crumb
  */
 void DCrumbTextFormat::setTagColor(const QColor &color)
 {
@@ -173,8 +182,9 @@ void DCrumbTextFormat::setTagColor(const QColor &color)
 }
 
 /*!
-  \brief DCrumbTextFormat::text
-  \return 返回标签的文本内容
+@~english
+  @brief DCrumbTextFormat::text return the text of the tag/crumb
+  @return the text content of the tag/crumb
  */
 QString DCrumbTextFormat::text() const
 {
@@ -182,8 +192,9 @@ QString DCrumbTextFormat::text() const
 }
 
 /*!
-  \brief DCrumbTextFormat::setText 设置文本内容（标签名称）
-  \a text 文本内容
+@~english
+  @brief DCrumbTextFormat::setText set the text content(name of the tag/crumb)
+  @param[in] text the text content
  */
 void DCrumbTextFormat::setText(const QString &text)
 {
@@ -191,8 +202,9 @@ void DCrumbTextFormat::setText(const QString &text)
 }
 
 /*!
-  \brief DCrumbTextFormat::textColor
-  \return 返回文本的颜色
+@~english
+  @brief DCrumbTextFormat::textColor return the color of the text
+  @return color of the text
  */
 QColor DCrumbTextFormat::textColor() const
 {
@@ -200,8 +212,9 @@ QColor DCrumbTextFormat::textColor() const
 }
 
 /*!
-  \brief DCrumbTextFormat::setTextColor 设置文本颜色
-  \a color 文本的颜色
+@~english
+  @brief DCrumbTextFormat::setTextColor set the color of the text
+  @param[in] color color of the text
  */
 void DCrumbTextFormat::setTextColor(const QColor &color)
 {
@@ -209,8 +222,9 @@ void DCrumbTextFormat::setTextColor(const QColor &color)
 }
 
 /*!
-  \brief DCrumbTextFormat::background
-  \return 返回背景画刷
+@~english
+  @brief DCrumbTextFormat::background return the background brush
+  @return the background brush
  */
 QBrush DCrumbTextFormat::background() const
 {
@@ -218,8 +232,9 @@ QBrush DCrumbTextFormat::background() const
 }
 
 /*!
-  \brief DCrumbTextFormat::setBackground 设置背景
-  \a background 背景画刷
+@~english
+  @brief DCrumbTextFormat::setBackground set the backfround brush
+  @param[in] background the backfround brush
  */
 void DCrumbTextFormat::setBackground(const QBrush &background)
 {
@@ -227,8 +242,9 @@ void DCrumbTextFormat::setBackground(const QBrush &background)
 }
 
 /*!
-  \brief DCrumbTextFormat::backgroundRadius
-  \return 返回背景的圆角
+@~english
+  @brief DCrumbTextFormat::backgroundRadius return the background corner radius
+  @return the background corner radius
  */
 int DCrumbTextFormat::backgroundRadius() const
 {
@@ -236,8 +252,9 @@ int DCrumbTextFormat::backgroundRadius() const
 }
 
 /*!
-  \brief DCrumbTextFormat::setBackgroundRadius 设置背景圆角程度
-  \a radius 圆角的大小
+@~english
+  @brief DCrumbTextFormat::setBackgroundRadius set the background corner radius
+  @param[in] radius the background corner radius
  */
 void DCrumbTextFormat::setBackgroundRadius(int radius)
 {
@@ -248,7 +265,7 @@ DCrumbTextFormat::DCrumbTextFormat(int objectType)
 {
     setObjectType(objectType);
 
-    setBackground(getGradientBrush(static_cast<Background>(qrand() % 12)));
+    setBackground(getGradientBrush(static_cast<Background>(QRandomGenerator::global()->generate() % 12)));
     setTextColor(Qt::white);
 #if QT_VERSION < QT_VERSION_CHECK(5, 12, 0)
     setVerticalAlignment(QTextCharFormat::AlignBaseline);
@@ -277,17 +294,18 @@ public:
         widgetLeft = new QWidget(qq);
         widgetRight = new QWidget(qq);
         crumbRadius = DStyle::pixelMetric(qq->style(), DStyle::PM_FrameRadius);
+        panelFrame = new DCrumbEditPanelFrame(qq);
+        panelFrame->stackUnder(qq->viewport());
 
         widgetTop->setAccessibleName("DCrumbEditTopWidget");
         widgetBottom->setAccessibleName("DCrumbEditBottomWidget");
         widgetLeft->setAccessibleName("DCrumbEditLeftWidget");
         widgetRight->setAccessibleName("DCrumbEditRightWidget");
+        panelFrame->setAccessibleName("DCrumbEditPanelFrame");
     }
 
     void registerHandler(QAbstractTextDocumentLayout *layout)
     {
-        D_Q(DCrumbEdit);
-
         for (int i = QTextFormat::UserObject + 1; ; ++i) {
             if (!layout->handlerForObject(i)) {
                 objectType = i;
@@ -359,7 +377,9 @@ public:
         if (cursor.charFormat().objectType() != objectType)
             return false;
 
-        DCrumbTextFormat format(cursor.charFormat());
+        auto fmt = q->document()->documentLayout()->formatAt(mousePos);
+        DCrumbTextFormat format = formats.value(fmt.stringProperty(QTextFormat::UserProperty + 1));
+
         currentText = format.text();
         currentBrush = format.background();
 
@@ -371,7 +391,8 @@ public:
 
         makeCrumb();
 
-        if (mousePos.x() < q->cursorRect().left())
+        if (mousePos.x() < q->cursorRect().left() ||
+            mousePos.y() < q->cursorRect().top())
             cursor.setPosition(cursor.position() - 1, QTextCursor::KeepAnchor);
         else
             cursor.setPosition(cursor.position() + 1, QTextCursor::KeepAnchor);
@@ -516,6 +537,7 @@ public:
     int objectType;
     bool crumbReadOnly = false;
     int crumbRadius = 2;
+    bool explicitCrumbRadius = false;
     QString splitter = ",";
     QStringList formatList;
     QMap<QString, DCrumbTextFormat> formats;
@@ -523,6 +545,7 @@ public:
     bool dualClickMakeCrumb = false;
     QString currentText;
     QBrush currentBrush;
+    DCrumbEditPanelFrame* panelFrame = nullptr;
 
 public:
     QWidget* widgetTop;
@@ -541,9 +564,9 @@ QSizeF CrumbObjectInterface::intrinsicSize(QTextDocument *doc, int posInDocument
     int radius = crumb_format.backgroundRadius();
 
     if (crumb_format.tagColor().isValid())
-        return QSizeF(font_metrics.width(crumb_format.text()) + font_metrics.height() + radius + 2, font_metrics.height() + 2);
+        return QSizeF(font_metrics.horizontalAdvance(crumb_format.text()) + font_metrics.height() + radius + 2, font_metrics.height() + 2);
 
-    return QSizeF(font_metrics.width(crumb_format.text()) + 2 * radius + 2, font_metrics.height() + 2 + TopMargin *2);
+    return QSizeF(font_metrics.horizontalAdvance(crumb_format.text()) + 2 * radius + 2, font_metrics.height() + 2 + TopMargin *2);
 }
 
 void CrumbObjectInterface::drawObject(QPainter *painter, const QRectF &rect,
@@ -591,11 +614,11 @@ QBrush CrumbObjectInterface::backgroundBrush(const QRect &rect, const QBrush &br
 }
 
 /*!
-    \class Dtk::Widget::DCrumbEdit
+@~english
+    @class Dtk::Widget::DCrumbEdit
     \inmodule dtkwidget
 
-    \brief 标签输入控件.
-    \brief Tag Edit Widget.
+    @brief Tag Edit Widget.
 
     DCrumbEdit provide a edit widget as a container for user entered Tags (or say, Crumbs), and allow user edit
     the existed tags inside this widget. Tags comes with different text, each of the tags inside the same DCrumbEdit should
@@ -606,15 +629,8 @@ QBrush CrumbObjectInterface::backgroundBrush(const QRect &rect, const QBrush &br
     DCrumbEdit allowed user add a tag by providing a simple QString or provide a custom DCrumbTextFormat object.
     Refer to appendCrumb() and insertCrumb() to see the usage. To get a list of tags/crumbs, see crumbList()
 
-    DCrumbEdit 提供了一个编辑框，编辑框内可包含若干个标签，并允许通过用户输入来编辑这些标签。编辑框所包含的标签可通过标签的文字
-    内容确定唯一的标签，即编辑框所包含的标签内容（字符串值）均不重复。
-
-    编辑框中包含的标签的主体为字符串，除文字外，每个标签可以对应其不同的颜色等样式，对于可供使用的样式请参见 DCrumbTextFormat 。
-    DCrumbEdit 允许通过给定字符串的形式便捷的向其中添加一个默认样式的标签，也可以通过自行构建标签文字样式。请参见 insertCrumb()
-    和 appendCrumb() 的不同重载。可以通过 crumbList() 获得当前标签输入控件中包含的标签列表。
-
-    \image html DCrumbEdit.png
-    \sa DCrumbTextFormat
+    @image html DCrumbEdit.png
+    @sa DCrumbTextFormat
 */
 
 DCrumbEdit::DCrumbEdit(QWidget *parent)
@@ -623,11 +639,13 @@ DCrumbEdit::DCrumbEdit(QWidget *parent)
 {
     Q_D(DCrumbEdit);
 
-    qsrand(QTime(0, 0, 0).secsTo(QTime::currentTime()));
-
+    int frameRadius = DStyle::pixelMetric(style(), DStyle::PM_FrameRadius);
+    int margins = DStyle::pixelMetric(style(), DStyle::PM_FrameMargins);
     viewport()->setAutoFillBackground(false);
     viewport()->setAccessibleName("DCrumbViewport");
     setFrameShape(QFrame::NoFrame);
+    int margin = frameRadius / 2 + margins + 2;
+    setViewportMargins(margin, margin, margin, margin);
 
     d->widgetTop->setFixedWidth(1);
     d->widgetBottom->setFixedWidth(1);
@@ -650,23 +668,18 @@ DCrumbEdit::DCrumbEdit(QWidget *parent)
 }
 
 /*!
-  \brief 像标签编辑控件中插入新的标签
-  \brief Insert new tag/crumb to the crumb edit widget at the given position.
+@~english
+  @brief Insert new tag/crumb to the crumb edit widget at the given position.
   
-  \a format 一个 DCrumbTextFormat 对象.
-  \a format a DCrumbTextFormat.
-  \a pos 待插入的位置.
-  \a pos position to be inserted.
-  
-  通过给定的 DCrumbTextFormat 对象所描述的属性创建新的标签并追加到标签编辑控件中。若要创建一个直接可供使用的 DCrumbTextFormat
-  对象，可以考虑使用 makeTextFormat() 。
+  @param[in] format a DCrumbTextFormat.
+  @param[in] pos position to be inserted.
+
   Insert new tag/crumb with the provided DCrumbTextFormat at the given position. To create a ready-to-use
   DCrumbTextFormat object, call makeTextFormat().
   
-  \return 插入标签成功时返回 true，否则返回 false.
-  \return true if we appended a new tag into the crumb edit widget.
+  @return true if we appended a new tag into the crumb edit widget.
   
-  \sa makeTextFormat(), insertCrumb()
+  @sa makeTextFormat()
  */
 bool DCrumbEdit::insertCrumb(const DCrumbTextFormat &format, int pos)
 {
@@ -689,21 +702,17 @@ bool DCrumbEdit::insertCrumb(const DCrumbTextFormat &format, int pos)
 }
 
 /*!
-  \brief 像标签编辑控件中追加新的标签
-  \brief Append new tag/crumb to the crumb edit widget.
+@~english
+  @brief Append new tag/crumb to the crumb edit widget.
   
-  \a format 一个 DCrumbTextFormat 对象.
-  \a format a DCrumbTextFormat.
+  @param[in] format a DCrumbTextFormat.
   
-  通过给定的 DCrumbTextFormat 对象所描述的属性创建新的标签并追加到标签编辑控件中。若要创建一个直接可供使用的 DCrumbTextFormat
-  对象，可以考虑使用 makeTextFormat() 。
   Append new tag/crumb with the provided DCrumbTextFormat. To create a ready-to-use DCrumbTextFormat object,
   call makeTextFormat().
+
+  @return true if we appended a new tag into the crumb edit widget.
   
-  \return 插入标签成功时返回 true，否则返回 false.
-  \return true if we appended a new tag into the crumb edit widget.
-  
-  \sa makeTextFormat(), insertCrumb()
+  @sa makeTextFormat()
  */
 bool DCrumbEdit::appendCrumb(const DCrumbTextFormat &format)
 {
@@ -724,21 +733,15 @@ bool DCrumbEdit::appendCrumb(const DCrumbTextFormat &format)
 }
 
 /*!
-  \brief 像标签编辑控件中插入新的标签
-  \brief Insert new tag/crumb to the crumb edit widget.
+@~english
+  @brief Insert new tag/crumb to the crumb edit widget.
   
-  \a text 标签的文字内容.
-  \a text of the tag/crumb.
-  \a pos 待插入的位置.
-  \a pos position to be inserted.
+  @param[in] text of the tag/crumb.
+  @param[in] pos position to be inserted.
   
-  通过给定的文字创建新的标签并插入到标签编辑控件中的指定位置。
   Insert new tag/crumb with the provided text to the given position.
   
-  \return 插入标签成功时返回 true，否则返回 false.
-  \return true if we appended a new tag into the crumb edit widget.
-  
-  \sa appendCrumb()
+  @return true if we appended a new tag into the crumb edit widget.
  */
 bool DCrumbEdit::insertCrumb(const QString &text, int pos)
 {
@@ -750,19 +753,14 @@ bool DCrumbEdit::insertCrumb(const QString &text, int pos)
 }
 
 /*!
-  \brief 像标签编辑控件中追加新的标签
-  \brief Append new tag/crumb to the crumb edit widget.
+@~english
+  @brief Append new tag/crumb to the crumb edit widget.
   
-  \a text 标签的文字内容.
-  \a text of the tag/crumb.
+  @param[in] text of the tag/crumb.
   
-  通过给定的文字创建新的标签并追加到标签编辑控件中。
   Append new tag/crumb with the provided text.
   
-  \return 插入标签成功时返回 true，否则返回 false.
-  \return true if we appended a new tag into the crumb edit widget.
-  
-  \sa insertCrumb()
+  @return true if we appended a new tag into the crumb edit widget.
  */
 bool DCrumbEdit::appendCrumb(const QString &text)
 {
@@ -774,9 +772,10 @@ bool DCrumbEdit::appendCrumb(const QString &text)
 }
 
 /*!
-  \brief 检查当前控件是否已经包含了 \a text 标签
-  \a text 待检查的标签文字名称
-  \return 如果包含，返回 true
+@~english
+  @brief Check whether this widget already has the tag/crumb setting param "text" as text content
+  @param[in] text the text(also the name) of the tag/crumb
+  @return True if the widget does have such a tag/crumb and False if not
  */
 bool DCrumbEdit::containCrumb(const QString &text) const
 {
@@ -786,8 +785,8 @@ bool DCrumbEdit::containCrumb(const QString &text) const
 }
 
 /*!
-  \brief Get a list of crumb/tags inside the crumb edit widget.
-  \brief 取得标签输入控件内已包含的标签列表
+@~english
+  @brief Get a list of crumb/tags inside the crumb edit widget.
  */
 QStringList DCrumbEdit::crumbList() const
 {
@@ -797,8 +796,8 @@ QStringList DCrumbEdit::crumbList() const
 }
 
 /*!
-  \brief Get the DCrumbTextFormat matched the given tag \a text name.
-  \brief 根据标签名称取得对应的标签样式属性 DCrumbTextFormat 对象
+@~english
+  @brief Get the DCrumbTextFormat matched the given tag @param[in] text name.
  */
 DCrumbTextFormat DCrumbEdit::crumbTextFormat(const QString &text) const
 {
@@ -808,11 +807,10 @@ DCrumbTextFormat DCrumbEdit::crumbTextFormat(const QString &text) const
 }
 
 /*!
-  \brief 创建一个直接可用的 DCrumbTextFormat 对象.
-  \brief create a ready-to-use DCrumbTextFormat object.
+@~english
+  @brief create a ready-to-use DCrumbTextFormat object.
 
-  \return 创建的 DCrumbTextFormat 对象
-  \return the created DCrumbTextFormat object
+  @return the created DCrumbTextFormat object
  */
 DCrumbTextFormat DCrumbEdit::makeTextFormat() const
 {
@@ -820,22 +818,20 @@ DCrumbTextFormat DCrumbEdit::makeTextFormat() const
 
     DCrumbTextFormat format(d->objectType);
 
-    format.setFontFamily(font().family());
+    format.setFontFamilies(font().families());
     format.setBackgroundRadius(d->crumbRadius);
 
     return format;
 }
 
 /*!
-  \brief 根据所给的标签类型（颜色）创建一个直接可用的 DCrumbTextFormat 对象.
-  \brief create a ready-to-use DCrumbTextFormat object with the given color.
+@~english
+  @brief create a ready-to-use DCrumbTextFormat object with the given color.
   
-  将根据所给的（颜色）类型创建一个新的 DCrumbTextFormat 对象，并将其内文字属性设为颜色的名称。
   Create a ready-to-use DCrumbTextFormat object with the given color, and set its text
   as the color name.
-  
-  \return 创建的 DCrumbTextFormat 对象
-  \return the created DCrumbTextFormat object
+
+  @return the created DCrumbTextFormat object
  */
 DCrumbTextFormat DCrumbEdit::makeTextFormat(DCrumbEdit::CrumbType type) const
 {
@@ -935,9 +931,10 @@ QString DCrumbEdit::splitter() const
 }
 
 /*!
-  \brief 设置或取消设置标签编辑控件的只读状态
+@~english
+  @brief set or cancel setting the tag\crumb to be readonly
 
-  \a crumbReadOnly 是否只读.
+  @param[in] crumbReadOnly True means readonly, while False means not.
  */
 void DCrumbEdit::setCrumbReadOnly(bool crumbReadOnly)
 {
@@ -947,23 +944,27 @@ void DCrumbEdit::setCrumbReadOnly(bool crumbReadOnly)
 }
 
 /*!
-  \brief 设置控件圆角角度
+@~english
+  @brief set the corner radius of the tag/crumb
 
-  \a crumbRadius 圆角角度.
+  @param[in] crumbRadius the corner radius of the tag/crumb.
  */
 void DCrumbEdit::setCrumbRadius(int crumbRadius)
 {
     D_D(DCrumbEdit);
 
     d->crumbRadius = crumbRadius;
+    d->explicitCrumbRadius = true;
 }
 
 /*!
-  \brief 设置分割符
+@~english
+  @brief set the splitter
   
-  设置表示划分标签边界的分割字符，可用于一次性输入多个以给定分隔符分割的标签。
+  set the splitter representing the boundary of the tag/crumb.
+  It can be used to input multiple tags/crumbs separated by a given splitter at one time.
 
-  \a splitter 分割线字符.
+  @param[in] splitter the splitter character.
  */
 void DCrumbEdit::setSplitter(const QString &splitter)
 {
@@ -991,25 +992,44 @@ bool DCrumbEdit::event(QEvent *e)
         d->widgetBottom->setFixedHeight(frame_radius);
         d->widgetLeft->setFixedWidth(frame_radius);
         d->widgetRight->setFixedWidth(frame_radius);
+    } else if (e->type() == QEvent::Resize) {
+        d->panelFrame->resize(size());
+    } else if (e->type() == QEvent::StyleChange)  {
+        int frameRadius = DStyle::pixelMetric(style(), DStyle::PM_FrameRadius);
+        // update crumbRadius if not set.
+        if (!d->explicitCrumbRadius) {
+        d->crumbRadius = frameRadius;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        auto collection = document()->docHandle()->formatCollection();
+#else
+        auto collection = QTextDocumentPrivate::get(document())->formatCollection();
+#endif
+            for (int i = 0; i < collection->numFormats(); ++i) {
+                // only update format in d->formats.
+                if (!collection->format(i).hasProperty(QTextFormat::UserProperty + 1))
+                    continue;
+                const auto key = collection->format(i).property(QTextFormat::UserProperty + 1).toString();
+                if (d->formats.contains(key))
+                    collection->formats[i].setProperty(QTextFormat::UserProperty + 4, crumbRadius());
+            }
+            for (auto iter = d->formats.begin(); iter != d->formats.end(); iter++) {
+                iter->setBackgroundRadius(crumbRadius());
+            }
+        }
+
+        int margins = DStyle::pixelMetric(style(), DStyle::PM_FrameMargins);
+        int margin = frameRadius / 2 + margins + 2;
+        setViewportMargins(margin, margin, margin, margin);
     }
 
     return QTextEdit::event(e);
 }
 
-/*!\reimp */
 void DCrumbEdit::paintEvent(QPaintEvent *event)
 {
-    QPainter p(viewport());
-
-    QStyleOptionFrame panel;
-    initStyleOption(&panel);
-    panel.rect = viewport()->rect();
-    style()->drawPrimitive(QStyle::PE_PanelLineEdit, &panel, &p, this);
-
     QTextEdit::paintEvent(event);
 }
 
-/*!\reimp */
 void DCrumbEdit::keyPressEvent(QKeyEvent *event)
 {
     D_D(DCrumbEdit);
@@ -1022,7 +1042,7 @@ void DCrumbEdit::keyPressEvent(QKeyEvent *event)
     } else if (event->key() == Qt::Key_Escape) {
         event->ignore();
     } else if (event == QKeySequence::SelectAll) {
-        // 当文本正在编辑并之前已存在颜色文本时，复制的文字会出现异常，这里按下全选时将正在编辑的文本转化为颜色文本
+        // When the text is being edited and there is already color text, the copied text will encounter an exception: use "Select All" will convert the edited text to color text
         d->makeCrumb();
         QTextEdit::keyPressEvent(event);
     } else {
@@ -1030,7 +1050,6 @@ void DCrumbEdit::keyPressEvent(QKeyEvent *event)
     }
 }
 
-/*!\reimp */
 void DCrumbEdit::mouseDoubleClickEvent(QMouseEvent *event)
 {
     D_D(DCrumbEdit);
@@ -1045,7 +1064,6 @@ void DCrumbEdit::mouseDoubleClickEvent(QMouseEvent *event)
         return QTextEdit::mouseDoubleClickEvent(event);
 }
 
-/*!\reimp */
 void DCrumbEdit::focusOutEvent(QFocusEvent *event)
 {
     D_D(DCrumbEdit);
@@ -1055,7 +1073,6 @@ void DCrumbEdit::focusOutEvent(QFocusEvent *event)
     QTextEdit::focusOutEvent(event);
 }
 
-/*!\reimp */
 QMimeData *DCrumbEdit::createMimeDataFromSelection() const
 {
     D_DC(DCrumbEdit);
@@ -1096,12 +1113,12 @@ QMimeData *DCrumbEdit::createMimeDataFromSelection() const
 
             format_list << f;
         } else {
-            // 有可编辑文本时 如果鼠标有选中状态需要添加可编辑文本
+            // When there is editable text, if the mouse is selected, editable text needs to be added
             if (pos < cursor.selectionStart())
                 continue;
 
             if (!text.isEmpty() && ((ch_it - 1) >= plain_text.begin()) && (*(ch_it - 1) == QChar::ObjectReplacementCharacter)) {
-                // 上一个字符不是第一个字符 且 上一个字符为标识字符
+                // The previous character is not the first character and is an identifier.
                 text.append(" ").append(*ch_it);
             } else {
                 text.append(*ch_it);
@@ -1116,7 +1133,6 @@ QMimeData *DCrumbEdit::createMimeDataFromSelection() const
     return mime;
 }
 
-/*!\reimp */
 bool DCrumbEdit::canInsertFromMimeData(const QMimeData *source) const
 {
     if (source->hasFormat("deepin/dtkwidget-DCrumbTextFormat-data"))
@@ -1125,7 +1141,6 @@ bool DCrumbEdit::canInsertFromMimeData(const QMimeData *source) const
     return QTextEdit::canInsertFromMimeData(source);
 }
 
-/*!\reimp */
 void DCrumbEdit::insertFromMimeData(const QMimeData *source)
 {
     if (!source->hasFormat("deepin/dtkwidget-DCrumbTextFormat-data"))
