@@ -1,32 +1,18 @@
-/*
-* Copyright (C) 2021 ~ 2021 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     Ye ShanShan <yeshanshan@uniontech.com>
-*
-* Maintainer: Ye ShanShan <yeshanshan@uniontech.com>>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU Lesser General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU Lesser General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2021 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dfontcombobox.h"
 
 #include "private/dcombobox_p.h"
 #include <DObjectPrivate>
-
+#include <QScreen>
+#include <QWindow>
 #include <QListView>
 #include <QTableView>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QDesktopWidget>
+#endif
 #include <QEvent>
 #include <QApplication>
 
@@ -44,7 +30,7 @@ public:
 
     virtual ~DFontComboBoxPrivate() override;
 
-    // DFontComboBox的具体实现采用QFontComboBox的实现
+    // The specific implementation of DFontComboBox adopts the implementation of QFontComboBox
     QFontComboBox* impl;
 };
 
@@ -54,17 +40,22 @@ DFontComboBoxPrivate::~DFontComboBoxPrivate()
 }
 
 /*!
- * \~chinese \class DFontComboBox
- * \~chinese \brief DFontComboBox 字体选择下拉列表
- * \~chinese \li DFontComboBox 提供了系统字体选择功能
- *
- * \~chinese \note\row 代码示例
- * \~chinese \note\row DFontComboBox *fontComboBox = new DFontComboBox();
- */
+@~english
+  @class DFontComboBox
+  @brief The DFontComboBox class provides combobox for selecting font
 
+  The DFontComboBox class provides functions to select system font
+
+  @code 
+  #code example
+  DFontComboBox *fontComboBox = new DFontComboBox();
+  @endcode
+  
+  @image html DFontComboBox.png
 /*!
- * \chinese \brief DFontComboBox 构造函数
- * \chinese \param parent参数被发送到 DComboBox 构造函数
+@~english
+  @brief DFontComboBox constructor.
+  @param[in] parent is passed to DComboBox constructor
  */
 DFontComboBox::DFontComboBox(QWidget *parent)
     : DComboBox(*new DFontComboBoxPrivate(this), parent)
@@ -72,8 +63,13 @@ DFontComboBox::DFontComboBox(QWidget *parent)
     setModel(d_func()->impl->model());
     setItemDelegate(d_func()->impl->itemDelegate());
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     connect(this, SIGNAL(currentIndexChanged(QString)),
             d_func()->impl, SIGNAL(currentIndexChanged(QString)));
+#else
+    connect(this, SIGNAL(currentIndexChanged(int)),
+            d_func()->impl, SIGNAL(currentIndexChanged(int)));
+#endif
     connect(d_func()->impl, SIGNAL(currentFontChanged(const QFont &)),
             this, SIGNAL(currentFontChanged(const QFont &)));
 }
@@ -83,7 +79,8 @@ DFontComboBox::~DFontComboBox()
 }
 
 /*!
- * \~chinese \brief 与QFontComboBox::setWritingSystem相同
+@~english
+  @brief same as QFontComboBox::setWritingSystem
  */
 void DFontComboBox::setWritingSystem(QFontDatabase::WritingSystem script)
 {
@@ -92,7 +89,8 @@ void DFontComboBox::setWritingSystem(QFontDatabase::WritingSystem script)
 }
 
 /*!
- * \~chinese \brief 与QFontComboBox::writingSystem相同
+@~english
+  @brief same as QFontComboBox::writingSystem
  */
 QFontDatabase::WritingSystem DFontComboBox::writingSystem() const
 {
@@ -101,7 +99,8 @@ QFontDatabase::WritingSystem DFontComboBox::writingSystem() const
 }
 
 /*!
- * \~chinese \brief 与QFontComboBox::setFontFilters相同
+@~english
+  @brief same as QFontComboBox::setFontFilters
  */
 void DFontComboBox::setFontFilters(QFontComboBox::FontFilters filters)
 {
@@ -110,7 +109,8 @@ void DFontComboBox::setFontFilters(QFontComboBox::FontFilters filters)
 }
 
 /*!
- * \~chinese \brief 与QFontComboBox::fontFilters相同
+@~english
+  @brief same as QFontComboBox::fontFilters
  */
 QFontComboBox::FontFilters DFontComboBox::fontFilters() const
 {
@@ -119,7 +119,8 @@ QFontComboBox::FontFilters DFontComboBox::fontFilters() const
 }
 
 /*!
- * \~chinese \brief 与QFontComboBox::currentFont相同
+@~english
+  @brief same as QFontComboBox::currentFont
  */
 QFont DFontComboBox::currentFont() const
 {
@@ -128,7 +129,8 @@ QFont DFontComboBox::currentFont() const
 }
 
 /*!
- * \~chinese \brief 与QFontComboBox::sizeHint相同
+@~english
+  @brief same as QFontComboBox::sizeHint
  */
 QSize DFontComboBox::sizeHint() const
 {
@@ -137,7 +139,8 @@ QSize DFontComboBox::sizeHint() const
 }
 
 /*!
- * \~chinese \brief 与QFontComboBox::setCurrentFont相同
+@~english
+  @brief same as QFontComboBox::setCurrentFont
  */
 void DFontComboBox::setCurrentFont(const QFont &f)
 {
@@ -146,15 +149,18 @@ void DFontComboBox::setCurrentFont(const QFont &f)
 }
 
 /*!
- * \~chinese \brief 与QFontComboBox::event相同
+@~english
+  @brief same as QFontComboBox::event
  */
 bool DFontComboBox::event(QEvent *e)
 {
     if (e->type() == QEvent::Resize) {
         QListView *lview = qobject_cast<QListView*>(view());
         if (lview) {
-            lview->window()->setFixedWidth(qMin(width() * 5 / 3,
-                               QApplication::desktop()->availableGeometry(lview).width()));
+          lview->winId();
+          auto window = lview->window();
+          window->setFixedWidth(qMin(width() * 5 / 3,
+                               window->windowHandle()->screen()->availableGeometry().width()));
         }
     }
     return DComboBox::event(e);
