@@ -1,25 +1,14 @@
-/*
- * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dimagebutton.h"
 #include "dconstants.h"
 #include "dthememanager.h"
 #include "private/dimagebutton_p.h"
 
+#if DTK_VERSION < DTK_VERSION_CHECK(6, 0, 0, 0)
+
 #include <QMouseEvent>
 #include <QEvent>
 #include <QIcon>
@@ -183,7 +172,11 @@ DImageButton::~DImageButton()
 {
 }
 
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+void DImageButton::enterEvent(QEnterEvent *event)
+#else
 void DImageButton::enterEvent(QEvent *event)
+#endif
 {
     D_D(DImageButton);
 
@@ -741,3 +734,5 @@ QPixmap DImageButtonPrivate::loadPixmap(const QString &path)
 }
 
 DWIDGET_END_NAMESPACE
+
+#endif
