@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include <QRegularExpressionValidator>
 #include <QGuiApplication>
@@ -42,10 +29,11 @@ void DIpv4LineEditPrivate::init()
 {
     D_Q(DIpv4LineEdit);
 
-    // 和子edit保持一致不显示菜单
+    // Keep the consistency with the child edit and do not display the menu.
     q->setContextMenuPolicy(Qt::NoContextMenu);
-    // 带圆角的自绘制背景的frame，挡住背后的edit文字
+    // A frame with rounded corners is a self-drawn background that covers the text of the edit control behind it.
     DFrame *frame = new DFrame(q);
+    frame->setAccessibleName("DIpv4LineEditFrame");
     frame->setFrameRounded(true);
     frame->setFrameShape(QFrame::NoFrame);
     editMainWidget = frame;
@@ -56,7 +44,7 @@ void DIpv4LineEditPrivate::init()
     QHBoxLayout *hbox_layout = new QHBoxLayout;
 
     hbox_layout->setSpacing(0);
-    hbox_layout->setMargin(0);
+    hbox_layout->setContentsMargins(0, 0, 0, 0);
     hbox_layout->addWidget(getEdit());
     hbox_layout->addWidget(getLabel());
     hbox_layout->addWidget(getEdit());
@@ -96,7 +84,7 @@ QLineEdit *DIpv4LineEditPrivate::getEdit()
     edit->setAttribute(Qt::WA_InputMethodEnabled, false);
     edit->setContextMenuPolicy(Qt::NoContextMenu);
     edit->installEventFilter(q);
-    // 禁止绘制子edit的焦点框
+    // Prohibit drawing the focus box of sub edit
     edit->setProperty("_d_dtk_noFocusRect", true);
 
     editList << edit;
@@ -115,7 +103,7 @@ void DIpv4LineEditPrivate::setFocus(bool focus)
 
     this->focus = focus;
 
-    // 焦点改变时边框重绘一下
+    // Redraw the border when the focus changes
     q->update();
     Q_EMIT q->focusChanged(focus);
 }
@@ -181,46 +169,46 @@ void DIpv4LineEditPrivate::_q_setIpLineEditText(const QString &text)
 }
 
 /*!
- * \~chinese \class DIpv4LineEdit
- * \~chinese \brief 类DIpv4LineEdit是专门用于输入ipv4格式文本的编辑框。
- *
- * \~chinese 此类内部由四个 \l QLineEdit 组合而成，输入框之间可以通过Tab/Shift+Tab快捷切
- * \~chinese 换光标，输入字符"."时会自动跳到下一个输入框。在使用左右方向键移动光标时会自动跨
- * \~chinese 越输入框，和在同一个输入框内光标的没有区别。和 \l QLineEdit 一样也可以使用快捷
- * \~chinese 键方便的复制粘贴文本，在粘贴时会自动根据ipv4的规则过滤掉非法字符。每个输入框的文
- * \~chinese 本内容必须要满足以下的正则规则：
- * \code{.unparsed}
- * ^(2[0-4]\d|25[0-5]|[01]?\d\d?)?$
- * \endcode
- * \~chinese \warning 不能使用DLineEdit和QLineEdit中的功能性函数
+@~english
+  @class Dtk::Widget::DIpv4LineEdit
+  \inmodule dtkwidget
+  @brief The class DIpv4LineEdit is specifically designed as an input box for entering text in IPv4 format.
+
+  This class is composed of four @ref`QLineEdit` objects. The user can switch the cursor between input boxes by using the `Tab/Shift+Tab` shortcut keys, and typing a "." will automatically move the cursor to the next input box. When moving the cursor using the left and right arrow keys, it will automatically cross input boxes, just like in a single input box. Similar to @ref `QLineEdit`, this class also supports shortcut keys for copying and pasting text, and illegal characters will be automatically filtered according to the rules for IPv4 addresses when pasting. The text in each input box must meet the following regular expression rules:
+  @code{.unparsed}
+  ^(2[0-4]\d|25[0-5]|[01]?\d\d?)?$
+  @endcode
+  @warning functional functions of DLineEdit and QLineEdit cannot be used.
  */
 
 /*!
-  * \~chinese \property DIpv4LineEdit::selectedText
-  * \~chinese \brief 选中的文本内容
-  * \~chinese \note 只读
-  * \~chinese \sa QLineEdit::selectedText
+@~english
+  @property DIpv4LineEdit::selectedText
+  @brief Selected Text Content
+  @note readOnly
+  @sa QLineEdit::selectedText
   */
 
 /*!
-  * \~chinese \property DIpv4LineEdit::placeholderText
-  * \~chinese \brief 输入框未输入内容时的占位文本，通常显示为灰色，当输入任意字符后就会被隐藏
-  * \~chinese \note 只读。默认为空字符串
-  * \~chinese \sa QLineEdit::placeholderText
+@~english
+  @property DIpv4LineEdit::placeholderText
+  @brief The placeholder text in the input box is typically displayed in gray when there is no input, and will be hidden once any character is entered.
+  @note readOnly. The default is an empty string
+  @sa QLineEdit::placeholderText
   */
 
 /*!
-  * \~chinese \property DIpv4LineEdit::clearButtonEnabled
-  * \~chinese \brief 是否在输入框上显示清理按钮
-  * \~chinese \note 只读。默认为 false
-  * \~chinese \sa QLineEdit::clearButtonEnabled
+@~english
+  @property DIpv4LineEdit::clearButtonEnabled
+  @brief Whether to display the cleaning button on the input box
+  @note read only。Default is false.
+  @sa QLineEdit::clearButtonEnabled
   */
 
 /*!
- * \~chinese \brief 构造DIpv4LineEdit类，和普通 \l QWidget 一样，可以传入一个QWidget指
- * \~chinese 针对象作为其父对象
- * \~chinese 管理的控件
- * \~chinese \param parent
+@~english
+  @brief To construct the DIpv4LineEdit class, like any regular @ref QWidget, a pointer to a QWidget object can be passed in as its parent object to manage the widget.
+  @a parent
  */
 DIpv4LineEdit::DIpv4LineEdit(QWidget *parent)
     : QLineEdit(parent)
@@ -230,17 +218,18 @@ DIpv4LineEdit::DIpv4LineEdit(QWidget *parent)
 }
 
 /*!
- * \~chinese \property DIpv4LineEdit::displayText
- * \~chinese \brief 输入框显示的文本内容
- * \~chinese
- * \~chinese 和 QLineEdit::displayText 不同，无论 \l echoMode 值为多少，都返回和 \l text 同样的内容
- * \~chinese
- * \~chinese \note 可读可写
- * \~chinese \sa QLineEdit::echoMode QLineEdit::text
+@~english
+  @property DIpv4LineEdit::displayText
+  @brief The text content displayed in the input box
+  
+  Unlike QLineEdit::displayText, this method returns the same content as @ref text, regardless of the value of @ref echoMode.
+  
+  @note Read-write
+  @sa QLineEdit::echoMode QLineEdit::text
  */
 
 /*!
- * \~chinese \return
+  @return
  */
 QString DIpv4LineEdit::displayText() const
 {
@@ -248,15 +237,16 @@ QString DIpv4LineEdit::displayText() const
 }
 
 /*!
- * \~chinese \property DIpv4LineEdit::cursorPosition
- * \~chinese \brief 当前光标所在位置
- * \~chinese
- * \~chinese \note 可读可写
- * \~chinese \sa QLineEdit::cursorPosition
+@~english
+  @property DIpv4LineEdit::cursorPosition
+  @brief Current cursor position
+  
+  @note Read-write
+  @sa QLineEdit::cursorPosition
  */
 
 /*!
- * \~chinese \return
+  @return
  */
 int DIpv4LineEdit::cursorPosition() const
 {
@@ -277,17 +267,18 @@ int DIpv4LineEdit::cursorPosition() const
 }
 
 /*!
- * \~chinese \property DIpv4LineEdit::alignment
- * \~chinese \brief 文本内容对齐方式
- * \~chinese
- * \~chinese 固定为 \l Qt::AlignHCenter
- * \~chinese
- * \~chinese \note 只读
- * \~chinese \sa QLineEdit::alignment
+@~english
+  @property DIpv4LineEdit::alignment
+  @brief Text Content Alignment
+  
+  Fixed as @ref Qt:: AlignHCenter
+  
+  @note readOnly
+  @sa QLineEdit::alignment
  */
 
 /*!
- * \~chinese \return
+  @return
  */
 Qt::Alignment DIpv4LineEdit::alignment() const
 {
@@ -295,13 +286,15 @@ Qt::Alignment DIpv4LineEdit::alignment() const
 }
 
 /*!
- * \~chinese \property DIpv4LineEdit::acceptableInput
- * \~chinese \note 只读
- * \~chinese \sa QLineEdit::acceptableInput
+@~english
+  @property DIpv4LineEdit::acceptableInput
+  @brief Check if all QLineEdit objects in the DIPv4LineEdit class have acceptable inputs
+  @note readOnly
+  @sa QLineEdit::acceptableInput
  */
 
 /*!
- * \~chinese \return
+  @return
  */
 bool DIpv4LineEdit::hasAcceptableInput() const
 {
@@ -317,13 +310,15 @@ bool DIpv4LineEdit::hasAcceptableInput() const
 }
 
 /*!
- * \~chinese \property DIpv4LineEdit::readOnly
- * \~chinese \note 可读可写
- * \~chinese \sa QLineEdit::readOnly
+@~english
+  @property DIpv4LineEdit::isReadOnly
+  @brief Check if the first QLineEdit object in the DIPv4LineEdit class is in read-only mode
+  @note Read-write
+  @sa QLineEdit::readOnly
  */
 
 /*!
- * \~chinese \return
+  @return
  */
 bool DIpv4LineEdit::isReadOnly() const
 {
@@ -331,8 +326,11 @@ bool DIpv4LineEdit::isReadOnly() const
 }
 
 /*!
- * \~chinese \param cursorPosition
- * \~chinese \sa cursorPosition
+@~english
+  @property DIpv4LineEdit::setCursorPosition
+  @brief Move the cursor to the specified position and set the focus to the QLineEdit object containing that position
+  @a cursorPosition
+  @sa cursorPosition
  */
 void DIpv4LineEdit::setCursorPosition(int cursorPosition)
 {
@@ -354,8 +352,11 @@ void DIpv4LineEdit::setCursorPosition(int cursorPosition)
 }
 
 /*!
- * \~chinese \param readOnly
- * \~chinese \sa readOnly
+@~english
+  @property DIpv4LineEdit::setReadOnly
+  @brief set whether all QLineEdit objects in the DIPv4LineEdit object are in read-only mode
+  @a readOnly
+  @sa readOnly
  */
 void DIpv4LineEdit::setReadOnly(bool readOnly)
 {
@@ -367,10 +368,12 @@ void DIpv4LineEdit::setReadOnly(bool readOnly)
 }
 
 /*!
- * \~chinese \brief 使用此方法选中文本时会把四个输入框当做一个看待
- * \~chinese \param start
- * \~chinese \param length
- * \~chinese \sa QLineEdit::setSelection
+@~english
+  @property DIpv4LineEdit::setSelection
+  @brief When using this method to select text, the four input boxes will be treated as one
+  @a start
+  @a length
+  @sa QLineEdit::setSelection
  */
 void DIpv4LineEdit::setSelection(int start, int length)
 {
@@ -399,8 +402,10 @@ void DIpv4LineEdit::setSelection(int start, int length)
 }
 
 /*!
- * \~chinese \brief 选中所有输入框的全部内容
- * \~chinese \sa QLineEdit::selectAll
+@~english
+  @property DIpv4LineEdit::selectAll
+  @brief Select all contents of all input boxes
+  @sa QLineEdit::selectAll
  */
 void DIpv4LineEdit::selectAll()
 {
@@ -413,6 +418,15 @@ void DIpv4LineEdit::selectAll()
     QLineEdit::selectAll();
 }
 
+/*!
+@~english
+  @property DIpv4LineEdit::eventFilter
+  @brief Handle keyboard, mouse, and other events in input boxes to correctly respond to user input and actions.
+  @param obj The target object of the event.
+  @param e The event object.
+  @return bool Returns true if the event has been handled; otherwise returns false.
+ */
+
 bool DIpv4LineEdit::eventFilter(QObject *obj, QEvent *e)
 {
     if (e->type() == QEvent::KeyPress) {
@@ -422,7 +436,7 @@ bool DIpv4LineEdit::eventFilter(QObject *obj, QEvent *e)
             QKeyEvent *event = static_cast<QKeyEvent *>(e);
 
             if (event) {
-                // 按住shlft+left/right 时选中当前的edit文字，而非移动光标
+                // Select the current edit text while holding down shlft+left/right, instead of moving the cursor
                 if (event->modifiers() == Qt::ShiftModifier &&
                     (event->key() == Qt::Key_Left ||
                      event->key() == Qt::Key_Right)) {
@@ -528,7 +542,7 @@ bool DIpv4LineEdit::eventFilter(QObject *obj, QEvent *e)
         QLineEdit *edit = qobject_cast<QLineEdit *>(obj);
 
         if (edit) {
-            // focusProxy 只能设置一个， 所以每次focusIn时设置当前这个edit为FocusProxy吧
+            // focusProxy can only be set to one, so set the current edit control as the focusProxy each time focusIn is triggered.
             setFocusProxy(edit);
             QLineEdit::setCursorPosition(cursorPosition());
         }
@@ -553,6 +567,13 @@ bool DIpv4LineEdit::eventFilter(QObject *obj, QEvent *e)
     return QLineEdit::eventFilter(obj, e);
 }
 
+/*!
+@~english
+  @property DIpv4LineEdit::DIpv4LineEdit
+  @brief Constructor of DIpv4LineEdit class, used to create a DIpv4LineEdit object.
+  @param q A pointer to the internal data of the DIpv4LineEdit object.
+  @param parent The parent window object of the DIpv4LineEdit.
+ */
 DIpv4LineEdit::DIpv4LineEdit(DIpv4LineEditPrivate &q, QWidget *parent)
     : QLineEdit(parent)
     , DObject(q)
@@ -560,6 +581,12 @@ DIpv4LineEdit::DIpv4LineEdit(DIpv4LineEditPrivate &q, QWidget *parent)
 
 }
 
+/*!
+@~english
+  @property DIpv4LineEdit::resizeEvent
+  @brief Override the resizeEvent function to adjust the size and position of the input box.
+  @param event A QResizeEvent object that contains information about the window size change.
+ */
 void DIpv4LineEdit::resizeEvent(QResizeEvent *event)
 {
     D_D(DIpv4LineEdit);
