@@ -1,25 +1,10 @@
-/*
- * Copyright (C) 2019 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     zccrs <zccrs@live.com>
- *
- * Maintainer: zccrs <zhangjide@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "dlabel.h"
 #include "private/dlabel_p.h"
+#include "dtooltip.h"
 
 #include <DPaletteHelper>
 
@@ -28,17 +13,19 @@
 DWIDGET_BEGIN_NAMESPACE
 
 /*!
+@~english
   \class Dtk::Widget::DLabel
   \inmodule dtkwidget
-  \brief DLabel一个重新实现的 QLabel.
+  @brief DLabel a re-implementation QLabel.
 
-  DLabel提供了将 DLabel 显示在指定位置的函数
-  DLabel提供了改变字体颜色的函数
+  DLabel provides a function to display the DLabel at a specified location
+  DLabel provides a function to change the font color
  */
 
 /*!
-  \brief DLabel的构造函数.
-  \a parent 参数被发送到 QLabel 构造函数。
+@~english
+  @brief Constructor for DLabel.
+  \a parent The argument is sent to the QLabel constructor.
  */
 DLabel::DLabel(QWidget *parent, Qt::WindowFlags f)
     : QLabel(parent, f)
@@ -49,9 +36,10 @@ DLabel::DLabel(QWidget *parent, Qt::WindowFlags f)
 }
 
 /*!
-  \brief DLabel的构造函数.
-  \a text 文本信息
-  \a parent 参数被发送到 QLabel 构造函数。
+@~english
+  @brief Constructor for DLabel.
+  \a text Text message
+  \a parent Specifying the parent object.
  */
 DLabel::DLabel(const QString &text, QWidget *parent)
     : QLabel(text, parent)
@@ -67,8 +55,9 @@ DLabel::~DLabel()
 }
 
 /*!
-  \brief DLabel::setForegroundRole 显示的字体颜色
-  \a role 字体颜色（QPalette::ColorRole）
+@~english
+  @brief DLabel::setForegroundRole The font color displayed
+  \a role Font color（QPalette::ColorRole）
  */
 void DLabel::setForegroundRole(QPalette::ColorRole role)
 {
@@ -79,8 +68,9 @@ void DLabel::setForegroundRole(QPalette::ColorRole role)
 }
 
 /*!
-  \brief DLabel::setForegroundRole显示的字体颜色
-  \a color 字体颜色
+@~english
+  @brief DLabel::setForegroundRole The font color displayed
+  \a color Font color
  */
 void DLabel::setForegroundRole(DPalette::ColorType color)
 {
@@ -89,8 +79,9 @@ void DLabel::setForegroundRole(DPalette::ColorType color)
 }
 
 /*!
-  \brief DLabel::setElideMode 设置省略号显示的模式
-  \a elideMode 省略模式枚举
+@~english
+  @brief DLabel::setElideMode Set the mode of ellipsis display
+  \a elideMode Omitted schema enumeration
  */
 void DLabel::setElideMode(Qt::TextElideMode elideMode)
 {
@@ -103,8 +94,9 @@ void DLabel::setElideMode(Qt::TextElideMode elideMode)
 }
 
 /*!
-  \brief DLabel::elideMode 获取省略号的模式
-  \return 返回省略号的模式
+@~english
+  @brief DLabel::elideMode Gets the pattern of the ellipsis
+  \return Returns the pattern of ellipses
  */
 Qt::TextElideMode DLabel::elideMode() const
 {
@@ -113,9 +105,10 @@ Qt::TextElideMode DLabel::elideMode() const
 }
 
 /*!
-  \brief DLabel::DLabel 构造函数
-  \a dd 私有类成员变量
-  \a parent 父控件
+@~english
+  @brief DLabel::DLabel Constructor function
+  \a dd Private class member variables
+  \a parent Parent control
  */
 DLabel::DLabel(DLabelPrivate &dd, QWidget *parent)
     : QLabel(parent)
@@ -125,8 +118,9 @@ DLabel::DLabel(DLabelPrivate &dd, QWidget *parent)
 }
 
 /*!
-  \brief DLabel::initPainter 初始化 painter
-  \a painter painter 形参
+@~english
+  @brief DLabel::initPainter Initialization painter
+  \a painter painter parameter
  */
 void DLabel::initPainter(QPainter *painter) const
 {
@@ -139,8 +133,9 @@ void DLabel::initPainter(QPainter *painter) const
 }
 
 /*!
-  \brief DLabel::paintEvent
-  \a event 消息事件
+@~english
+  @brief DLabel::paintEvent
+  \a event Message event
   \sa QLabel::paintEvent()
  */
 void DLabel::paintEvent(QPaintEvent *event)
@@ -216,6 +211,23 @@ void DLabel::paintEvent(QPaintEvent *event)
                 const QFontMetrics fm(fontMetrics());
                 text = fm.elidedText(text, elideMode(), width(), Qt::TextShowMnemonic);
             }
+            const DToolTip::ToolTipShowMode &toolTipShowMode = DToolTip::toolTipShowMode(this);
+            if (toolTipShowMode != DToolTip::Default) {
+                const bool showToolTip = (toolTipShowMode == DToolTip::AlwaysShow)
+                        || ((toolTipShowMode == DToolTip::ShowWhenElided) && (d->text != text));
+                if (DToolTip::needUpdateToolTip(this, showToolTip)) {
+                    QString toolTip;
+                    if (showToolTip) {
+                        QTextOption textOption;
+                        textOption.setWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
+                        textOption.setTextDirection(opt.direction);
+                        textOption.setAlignment(Qt::Alignment(align));
+                        toolTip = DToolTip::wrapToolTipText(d->text, textOption);
+                    }
+                    this->setToolTip(toolTip);
+                    DToolTip::setShowToolTip(this, showToolTip);
+                }
+            }
             style->drawItemText(&painter, lr.toRect(), flags, palette, isEnabled(), text, foregroundRole());
         }
     } else
@@ -250,13 +262,33 @@ void DLabel::paintEvent(QPaintEvent *event)
         if (d->scaledcontents) {
             QSize scaledSize = cr.size() * devicePixelRatioF();
             if (!d->scaledpixmap || d->scaledpixmap->size() != scaledSize) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 8, 0)
                 if (!d->cachedimage)
+#endif
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 2)
                     d->cachedimage = new QImage(d->pixmap->toImage());
                 delete d->scaledpixmap;
+#else
+#if QT_VERSION < QT_VERSION_CHECK(6, 8, 0)
+                    d->cachedimage = QImage(d->pixmap->toImage());
+#endif
+                d->scaledpixmap.reset();
+#endif
+#if QT_VERSION < QT_VERSION_CHECK(6, 8, 0)
                 QImage scaledImage =
                     d->cachedimage->scaled(scaledSize,
                                            Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+#else
+                    d->scaledpixmap = d->pixmap->scaled(scaledSize,
+                                            Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+#endif
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 2)
                 d->scaledpixmap = new QPixmap(QPixmap::fromImage(scaledImage));
+#else
+#if QT_VERSION < QT_VERSION_CHECK(6, 8, 0)
+                d->scaledpixmap = QPixmap(QPixmap::fromImage(scaledImage));
+#endif
+#endif
                 d->scaledpixmap->setDevicePixelRatio(devicePixelRatioF());
             }
             pix = *d->scaledpixmap;
