@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2017 - 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: LGPL-3.0-or-later
 
@@ -7,7 +7,10 @@
 #include "dapplication.h"
 #include "dtitlebar.h"
 #include "dmessagemanager.h"
-
+#include "DBlurEffectWidget"
+#include "dsizemode.h"
+#include "dfeaturedisplaydialog.h"
+#include "denhancedwidget.h"
 #include "private/dmainwindow_p.h"
 #include "private/dapplication_p.h"
 
@@ -16,6 +19,14 @@
 #include <QWindow>
 #include <QMouseEvent>
 #include <QComboBox>
+#include <QToolBar>
+#include <QVBoxLayout>
+#include <qwidgetaction.h>
+#include <QScreen>
+
+#include <DWindowManagerHelper>
+#include <DAnchors>
+#include <DConfig>
 
 #ifdef Q_OS_MAC
 #include "osxwindow.h"
@@ -32,12 +43,8 @@ DMainWindowPrivate::DMainWindowPrivate(DMainWindow *qq)
 {
     titlebar = new DTitlebar(qq);
     titlebar->setAccessibleName("DMainWindowTitlebar");
-    auto noTitlebarEnabled = []{
-        QFunctionPointer enableNoTitlebar = qApp->platformFunction("_d_isEnableNoTitlebar");
-        bool enabled = qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool();
-        return enabled && enableNoTitlebar != nullptr;
-    };
-    if (DApplication::isDXcbPlatform() || noTitlebarEnabled()) {
+
+    if (DApplication::isDXcbPlatform() || DWindowManagerHelper::instance()->hasNoTitlebar()) {
         handle = new DPlatformWindowHandle(qq, qq);
         qq->setMenuWidget(titlebar);
     } else {
@@ -118,22 +125,32 @@ void DMainWindowPrivate::updateTitleShadowGeometry()
     if (!titleShadow)
         return;
 
-    QRect rect(0, titlebar->geometry().bottom() + 1, q->width(), titleShadow->sizeHint().height());
+    int x = (sidebarHelper && sidebarHelper->expanded()) ? sidebarHelper->width() : 0;
+    QRect rect(x, titlebar->geometry().bottom() + 1, q->width(), titleShadow->sizeHint().height());
     titleShadow->setGeometry(rect);
     // 全凭时会隐藏窗口标题栏，因此不应该显示标题栏的阴影
     titleShadow->setVisible(!q->isFullScreen());
     titleShadow->raise();
 }
 
+void DMainWindowPrivate::_q_autoShowFeatureDialog()
+{
+    D_QC(DMainWindow);
+    if (q->windowHandle()->isActive()) {
+        qApp->featureDisplayDialog()->show();
+        q->disconnect(q->windowHandle(), SIGNAL(activeChanged()), q, SLOT(_q_autoShowFeatureDialog()));
+    }
+}
+
 /*!
   \class Dtk::Widget::DMainWindow
   \inmodule dtkwidget
   \brief The DMainWindow class provides a main application window.
-  
+
   A main window provides a framework for building an application's user
   interface. DMainWindow has its own layout compared to QMainWindow,
   it has only title bar and content area, simpler and cleaner.
-  
+
   Developers can provide customized title bar and content to make the
   application rich functional.
  */
@@ -152,6 +169,18 @@ DMainWindow::DMainWindow(QWidget *parent)
     if (DGuiApplicationHelper::isTabletEnvironment()) {
         setWindowFlags(windowFlags() & ~(Qt::WindowMinMaxButtonsHint | Qt::WindowCloseButtonHint));
     }
+    DConfig config("org.deepin.dtk.preference");
+    bool isAutoDisplayFeature = config.value("autoDisplayFeature", false).toBool();
+    if (isAutoDisplayFeature) {
+        connect(this->windowHandle(), SIGNAL(activeChanged()), this, SLOT(_q_autoShowFeatureDialog()));
+        config.setValue("autoDisplayFeature", false);
+    }
+
+    D_D(DMainWindow);
+    DEnhancedWidget *hanceedWidget = new DEnhancedWidget(d->titlebar, parent);
+    connect(hanceedWidget, &DEnhancedWidget::heightChanged, hanceedWidget, [d]() {
+        d->updateTitleShadowGeometry();
+    });
 }
 
 /*!
@@ -165,10 +194,123 @@ DTitlebar *DMainWindow::titlebar() const
     return d->titlebar;
 }
 
+void DMainWindow::setSidebarWidget(QWidget *widget)
+{
+    D_D(DMainWindow);
+    if (d->sidebarWidget == widget)
+        return;
+
+    d->sidebarWidget = widget;
+    if (!d->sidebarHelper) {
+        d->sidebarHelper = new DSidebarHelper(this);
+        d->titlebar->setSidebarHelper(d->sidebarHelper);
+        QToolBar *tb = new QToolBar(this);
+        d->sidebarSep = new DVerticalLine(this);
+        d->sidebarSep->setWindowFlag(Qt::WindowStaysOnTopHint);
+        d->sidebarSep->setLineWidth(1);
+        d->sidebarSep->raise();
+        DAnchorsBase::setAnchor(d->sidebarSep, Qt::AnchorRight, tb, Qt::AnchorRight);
+
+        tb->layout()->setContentsMargins(QMargins(0, 0, 0, 0));
+        tb->setMovable(false);
+        auto *contentAction = tb->toggleViewAction();
+        contentAction->setVisible(false);
+        addToolBar(Qt::LeftToolBarArea, tb);
+        d->sidebarWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+
+        setAttribute(Qt::WA_TranslucentBackground);
+        auto bgBlurWidget = new DBlurEffectWidget(this);
+        bgBlurWidget->setBlendMode(DBlurEffectWidget::BehindWindowBlend);
+        bgBlurWidget->setMaskColor(DBlurEffectWidget::AutoColor);
+        bgBlurWidget->setObjectName("sidebarBlurWidget");
+        bgBlurWidget->setMaskAlpha(229); // 90%
+
+        QVBoxLayout *vlay = new QVBoxLayout(bgBlurWidget);
+        vlay->setContentsMargins(0, 0, 0, 0);
+        vlay->addWidget(d->sidebarWidget);
+        tb->addWidget(bgBlurWidget);
+        d->sidebarWidget->resize(tb->size());
+
+        connect(d->sidebarHelper, &DSidebarHelper::widthChanged, tb, &QToolBar::setFixedWidth);
+        connect(d->sidebarHelper, &DSidebarHelper::expandChanged, this, [tb, d] (bool expanded) {
+            tb->setVisible(expanded);
+            d->sidebarSep->setVisible(expanded);
+            d->updateTitleShadowGeometry();
+        });
+        connect(d->sidebarHelper, &DSidebarHelper::visibleChanged, tb, [tb, d] {
+            tb->setVisible(d->sidebarHelper->sectionVisible());
+            d->sidebarSep->setVisible(d->sidebarHelper->sectionVisible());
+            d->updateTitleShadowGeometry();
+        });
+
+        d->tb = tb;
+        d->sidebarHelper->setVisible(true);
+    }
+
+}
+
+QWidget *DMainWindow::sidebarWidget()
+{
+    D_DC(DMainWindow);
+    return d->sidebarWidget;
+}
+
+int DMainWindow::sidebarWidth() const
+{
+    D_DC(DMainWindow);
+    if (d->sidebarHelper)
+        return d->sidebarHelper->width();
+    return 0;
+}
+
+void DMainWindow::setSidebarWidth(int width)
+{
+    D_D(DMainWindow);
+    if (d->sidebarHelper)
+        d->sidebarHelper->setWidth(width);
+}
+
+#if DTK_VERSION < DTK_VERSION_CHECK(6, 0, 0, 0)
+bool DMainWindow::sidebarVisble() const
+{
+    return sidebarVisible();
+}
+#endif
+
+bool DMainWindow::sidebarVisible() const
+{
+    D_DC(DMainWindow);
+    if (d->sidebarHelper)
+        return d->sidebarHelper->visible();
+    return false;
+}
+
+void DMainWindow::setSidebarVisible(bool visible)
+{
+    D_D(DMainWindow);
+    if (d->sidebarHelper)
+        d->sidebarHelper->setVisible(visible);
+}
+
+bool DMainWindow::sidebarExpanded() const
+{
+    D_DC(DMainWindow);
+    if (d->sidebarHelper)
+        return d->sidebarHelper->expanded();
+    return false;
+}
+
+void DMainWindow::setSidebarExpanded(bool expended)
+{
+    D_D(DMainWindow);
+    if (d->sidebarHelper)
+        d->sidebarHelper->setExpanded(expended);
+}
+
 /*!
   \brief DMainWindow::isDXcbWindow
   \return Whether this window is dxcb backended.
-  
+
   Many features like blurred background and window clipping are supported
   only if the window is using the dxcb Qt platform plugin.
  */
@@ -272,10 +414,10 @@ QColor DMainWindow::shadowColor() const
 /*!
   \property DMainWindow::clipPath
   \brief This property holds the custom QPainterPath to be used to clip the window.
-  
+
   By default DMainWindow is clipped as a corner-rounded rectangle, but you can
   supply a custom QPainterPath to do custom shaped window.
-  
+
   \sa DMainWindow::frameMask
  */
 QPainterPath DMainWindow::clipPath() const
@@ -292,7 +434,7 @@ QPainterPath DMainWindow::clipPath() const
 /*!
   \property DMainWindow::frameMask
   \brief This property holds the mask to be applied on the window.
-  
+
   For better clip quality, for example antialiasing, use property
   DMainWindow::clipPath instead.
  */
@@ -336,9 +478,9 @@ bool DMainWindow::translucentBackground() const
 /*!
   \brief DMainWindow::enableSystemResize
   \return This property holds whether the window can be resized by the user.
-  
+
   The default value of this property is true.
-  
+
   You can set this property to false and implement the resize polizy of this
   window by you self.
  */
@@ -356,9 +498,9 @@ bool DMainWindow::enableSystemResize() const
 /*!
   \property DMainWindow::enableSystemMove
   \brief This property holds whether the window can be moved by the user.
-  
+
   The default value of this property is true.
-  
+
   You can set this property to false and choose the effective area to drag and move.
  */
 bool DMainWindow::enableSystemMove() const
@@ -390,10 +532,10 @@ bool DMainWindow::enableBlurWindow() const
 /*!
   \property DMainWindow::autoInputMaskByClipPath
   \brief This property holds whether the user input is masked by the clip path.
-  
+
   Sometimes you may want to handle events happening in the areas that are
   visually clipped by the setting DMainWindow::clipPath.
-  
+
   The default value of this property is true.
  */
 bool DMainWindow::autoInputMaskByClipPath() const
@@ -589,7 +731,7 @@ void DMainWindow::setEnableSystemMove(bool enableSystemMove)
 
 /*!
   \brief DMainWindow::setEnableBlurWindow　设置窗口模糊效果
-  \~shinese 开启此功能请设置setAttribute(Qt::WA_TranslucentBackground)
+  \~chinese 开启此功能请设置setAttribute(Qt::WA_TranslucentBackground)
   \a enableBlurWindow true开启模糊效果　false关闭模糊效果
  */
 void DMainWindow::setEnableBlurWindow(bool enableBlurWindow)
@@ -689,12 +831,18 @@ void DMainWindow::resizeEvent(QResizeEvent *event)
 
     d->updateTitleShadowGeometry();
 
+    if (sidebarWidget()) {
+        sidebarWidget()->resize(d->tb->size());
+        d->sidebarSep->resize({1, rect().height()});
+        d->sidebarSep->raise();
+    }
     return QMainWindow::resizeEvent(event);
 }
 
 void DMainWindow::changeEvent(QEvent *event)
 {
-    if (event->type() == QEvent::WindowStateChange) {
+    if (event->type() == QEvent::WindowStateChange ||
+            event->type() == QEvent::StyleChange) {
         D_D(DMainWindow);
         d->updateTitleShadowGeometry();
     }
@@ -703,3 +851,5 @@ void DMainWindow::changeEvent(QEvent *event)
 }
 
 DWIDGET_END_NAMESPACE
+
+#include "moc_dmainwindow.cpp"
