@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dsearchedit.h"
 #include "dpalette.h"
@@ -23,10 +10,11 @@
 
 #include <DSysInfo>
 #include <DGuiApplicationHelper>
+#include <DIconTheme>
 #undef ENABLE_AI
 
 #ifdef ENABLE_AI
-// 讯飞语言相关
+//iFlytek related
 #include "session_interface.h"
 #include "iat_interface.h"
 #endif
@@ -49,6 +37,10 @@
 
 DWIDGET_BEGIN_NAMESPACE
 DCORE_USE_NAMESPACE
+DGUI_USE_NAMESPACE
+
+constexpr int ANI_DURATION = 200;
+constexpr int HIDE_CURSOR_MARGIN = -4;
 
 #ifdef ENABLE_AI
 class VoiceDevice : public QIODevice
@@ -87,7 +79,7 @@ public:
             return false;
         }
 
-        // 清理旧的数据
+        // clear old massage
         m_message.clear();
 
         connect(m_iat, &ComIflytekAiserviceIatInterface::onEnd, this, &VoiceDevice::onEnd);
@@ -169,20 +161,22 @@ private:
 #endif
 
 /*!
+@~english
   \class Dtk::Widget::DSearchEdit
   \inmodule dtkwidget
-  \brief DSearchEdit 类提供了专门用来进行搜索的输入框控件.
+  @brief The DSearchEdit class provides input box widget specifically used for searching
   
-  相比于一般的输入框控件，DSearchEdit 提供了搜索按钮指示，用户使用起来会更加自然。
-  如图示：
-  \image html searchedit.png
-  
-  \warning DSearchEdit 与 QLineEdit、DLineEdit 没有继承关系，功能不兼容。
+  @details The DSearchEdit class inherits from the DLineEdit class.
+  Compared to regular input box widgets, DSearchEdit provides search button instructions，thus users can use it more naturally.
+  As shown in the figure：
+
+  @image html ../images/DSearchEdit.png
  */
 
 /*!
-  \brief DSearchEdit::DSearchEdit 是 DSearchEdit 类的构造函数.
-  \a parent 指定了控件的父控件。
+@~english
+  @brief DSearchEdit constructor
+  @param[in] parent is the parent widget。
  */
 DSearchEdit::DSearchEdit(QWidget *parent)
     : DLineEdit(*new DSearchEditPrivate(this), parent)
@@ -192,7 +186,7 @@ DSearchEdit::DSearchEdit(QWidget *parent)
     d->init();
     setSpeechToTextEnabled(false);
 
-    //平板模式下屏蔽搜索框右键菜单
+    //hide the right-click menu for searching box in tablet environment
     if (DGuiApplicationHelper::isTabletEnvironment()) {
         d->lineEdit->setContextMenuPolicy(Qt::NoContextMenu);
     }
@@ -204,8 +198,8 @@ DSearchEdit::~DSearchEdit()
 }
 
 /*!
-  \brief DSearchEdit::setPlaceHolder 设置灰色的占位符文本
-  \a placeHolder 占位符文本内容
+  @brief set gray placeholder text
+  @param[in] placeHolder is the content of placeholder text
  */
 void DSearchEdit::setPlaceHolder(QString placeHolder)
 {
@@ -217,8 +211,9 @@ void DSearchEdit::setPlaceHolder(QString placeHolder)
 }
 
 /*!
-  \brief DSearchEdit::placeHolder
-  \return 返回占位符文本内容
+@~english
+  @brief return the placeholder text
+  @return placeholder text content
  */
 QString DSearchEdit::placeHolder() const
 {
@@ -233,7 +228,8 @@ void DSearchEdit::clear()
 }
 
 /*!
-  \brief DSearchEdit::clearEdit 清除内容，退出编辑状态
+@~english
+  @brief clear the input and exit editing status
  */
 void DSearchEdit::clearEdit()
 {
@@ -251,7 +247,9 @@ bool DSearchEdit::isVoiceInput() const
 {
 #ifndef DTK_NO_MULTIMEDIA
     D_DC(DSearchEdit);
+#ifdef ENABLE_AI
     return d->voiceInput && d->voiceInput->state() == QAudio::ActiveState;
+#endif // 
 #else
     return false;
 #endif
@@ -275,7 +273,14 @@ DSearchEditPrivate::DSearchEditPrivate(DSearchEdit *q)
     , action(nullptr)
     , iconWidget(nullptr)
     , label(nullptr)
+    , animation(nullptr)
 {
+    if (ENABLE_ANIMATIONS && ENABLE_ANIMATION_SEARCH) {
+        animation = new QPropertyAnimation;
+        animation->setPropertyName("pos");
+        animation->setEasingCurve(QEasingCurve::OutCubic);
+        animation->setDuration(ANI_DURATION);
+    }
 }
 
 DSearchEditPrivate::~DSearchEditPrivate()
@@ -298,10 +303,10 @@ void DSearchEditPrivate::init()
 
     action = new QAction(q);
     action->setObjectName("_d_search_leftAction");
-    action->setIcon(QIcon::fromTheme("search_action"));
+    action->setIcon(DIconTheme::findQIcon("search_indicator"));
     q->lineEdit()->addAction(action, QLineEdit::LeadingPosition);
     action->setVisible(false);
-    iconbtn->setIconSize(QSize(32, 32));
+    iconbtn->setIconSize(QSize(20, 20));
 
     DPalette pe;
     QStyleOption opt;
@@ -324,14 +329,15 @@ void DSearchEditPrivate::init()
     iconWidget->setObjectName("iconWidget");
     iconWidget->setAccessibleName("DSearchEditIconWidget");
     QHBoxLayout *center_layout = new QHBoxLayout(iconWidget);
-    center_layout->setMargin(0);
-    center_layout->setSpacing(0);
+    center_layout->setContentsMargins(0, 0, 0, 0);
+    center_layout->setSpacing(6);
 
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
 
     center_layout->addWidget(iconbtn, 0, Qt::AlignVCenter);
     center_layout->addWidget(label, 0, Qt::AlignCenter);
+    center_layout->addSpacing(12 / qApp->devicePixelRatio());
     layout->addWidget(iconWidget, 0, Qt::AlignCenter);
 
     QAction* clearAction = q->lineEdit()->findChild<QAction *>(QLatin1String("_q_qlineeditclearaction"));
@@ -342,7 +348,7 @@ void DSearchEditPrivate::init()
         for (int i = 0; i < list.count(); i++) {
             if (list.at(i)->defaultAction() == clearAction) {
                 QToolButton *clearBtn = list.at(i);
-                //屏蔽lineedit清除按钮的槽函数,_q_clearFocus()获得有效的判断条件
+                //Block the private slots of the lineedit clear button,_q_clearFocus() gains effective jugding condition
                 q->disconnect(clearBtn, SIGNAL(clicked()), q->lineEdit(), nullptr);
                 q->connect(clearBtn, SIGNAL(clicked()), q, SLOT(_q_clearFocus()));
             }
@@ -351,18 +357,18 @@ void DSearchEditPrivate::init()
 
 #ifdef ENABLE_AI
     voiceAction = new QAction(q);
-    voiceAction->setIcon(QIcon::fromTheme("button_voice"));
+    voiceAction->setIcon(DIconTheme::findQIcon("button_voice"));
     voiceAction->setCheckable(true);
     voiceAction->setEnabled(false);
     lineEdit->addAction(voiceAction, QLineEdit::TrailingPosition);
 
     q->connect(voiceAction, SIGNAL(triggered(bool)), q, SLOT(_q_onVoiceActionTrigger(bool)));
-    // 语音输入按钮
+    // voice input button
     QDBusInterface testSpeechToText("com.iflytek.aiassistant",
                                "/aiassistant/iat",
                                "com.iflytek.aiassistant.iat",
                                QDBusConnection::sessionBus());
-    // 测试听写接口是否开启
+    // test whether the dictation interface is enabled
     QDBusPendingCall call = testSpeechToText.asyncCall("getIatEnable");
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, q);
     QObject::connect(watcher, &QDBusPendingCallWatcher::finished, q, [this](QDBusPendingCallWatcher *pWatcher) {
@@ -381,30 +387,74 @@ void DSearchEditPrivate::_q_toEditMode(bool focus)
 {
     D_Q(DSearchEdit);
 
-    if (focus  || !q->lineEdit()->text().isEmpty()) {
-        action->setVisible(true);
-        iconWidget->setVisible(false);
-        lineEdit->setPlaceholderText(placeholderText);
-    } else {
-        action->setVisible(false);
+    if (ENABLE_ANIMATIONS && ENABLE_ANIMATION_SEARCH) {
+        if (animation->state() == QPropertyAnimation::Running)
+            return;
+
+        auto textMargins = q->lineEdit()->textMargins();
+        QMargins marginsInAnimation(HIDE_CURSOR_MARGIN, 0, 0, 0);
+
+        if (!animation->parent())
+            animation->setParent(iconWidget);
+
+        animation->setTargetObject(iconWidget);
+        animation->setStartValue(QPoint(q->lineEdit()->geometry().center().x() - iconWidget->width() / 2, iconWidget->pos().y()));
+        animation->setEndValue(QPoint(10, iconWidget->pos().y()));
+
+        q->connect(animation, &QPropertyAnimation::finished, q, [q, this, textMargins]() {
+            q->lineEdit()->setTextMargins(textMargins);
+            if (animation->direction() == QPropertyAnimation::Direction::Forward) {
+                iconWidget->setVisible(false);
+                action->setVisible(true);
+                lineEdit->setPlaceholderText(placeholderText);
+            } else {
+                iconWidget->setVisible(true);
+                lineEdit->setPlaceholderText(QString());
+                iconWidget->move(QPoint(q->lineEdit()->geometry().center().x() - iconWidget->width() / 2, iconWidget->pos().y()));
+            }
+        });
+
+        if (!q->lineEdit()->text().isEmpty())
+            return;
+
+        if (focus) {
+            animation->setDirection(QPropertyAnimation::Direction::Forward);
+        } else {
+            action->setVisible(false);
+            animation->setDirection(QPropertyAnimation::Direction::Backward);
+        }
+
         iconWidget->setVisible(true);
-        lineEdit->setPlaceholderText(QString());
+        q->lineEdit()->setTextMargins(marginsInAnimation);
+        animation->start();
+    } else {
+        if (focus  || !q->lineEdit()->text().isEmpty()) {
+            action->setVisible(true);
+            iconWidget->setVisible(false);
+            lineEdit->setPlaceholderText(placeholderText);
+        } else {
+            action->setVisible(false);
+            iconWidget->setVisible(true);
+            lineEdit->setPlaceholderText(QString());
+        }
+
     }
 
 #ifdef ENABLE_AI
-    //焦点消失，清除语音check
+    //Focus disappears, clear voice check
     if (voiceAction) {
         voiceAction->setChecked(false);
         _q_onVoiceActionTrigger(false);
     }
 #endif
+
 }
 
 void DSearchEditPrivate::_q_onVoiceActionTrigger(bool checked)
 {
 #if (!defined DTK_NO_MULTIMEDIA) && (defined ENABLE_AI)
     if (checked) {
-        voiceAction->setIcon(QIcon::fromTheme("button_voice_active"));
+        voiceAction->setIcon(DIconTheme::findQIcon("button_voice_active"));
 
         if (!voiceInput) {
             QAudioFormat format;
@@ -424,7 +474,7 @@ void DSearchEditPrivate::_q_onVoiceActionTrigger(bool checked)
             }, Qt::QueuedConnection);
 
             q->connect(voiceIODevice, &VoiceDevice::finished, q, [q, this] {
-                // 自动结束录制
+                // end the recording automatically
                 voiceAction->setChecked(false);
                 _q_onVoiceActionTrigger(false);
                 Q_EMIT q->voiceInputFinished();
@@ -436,7 +486,7 @@ void DSearchEditPrivate::_q_onVoiceActionTrigger(bool checked)
         if (voiceIODevice->open(QIODevice::WriteOnly))
             voiceInput->start(voiceIODevice);
     } else {
-        voiceAction->setIcon(QIcon::fromTheme("button_voice"));
+        voiceAction->setIcon(DIconTheme::findQIcon("button_voice"));
 
         if (voiceInput) {
             voiceInput->stop();
