@@ -28,13 +28,11 @@ DWIDGET_BEGIN_NAMESPACE
 const int DefaultTitlebarHeight = 40;
 
 /*!
+  @~english
   \class Dtk::Widget::DSettingsDialog
   \inmodule dtkwidget
-
-  \brief 为使用DSettings的Dtk程序提供一个通用的设置对话框，这个对话框可以通过json配置文件来自动生成.
   \brief DSettingsDialog provide an common setting ui for deepin style application.
-  It's depend Dtk::Widget::DSettingsWidgetFactory to auot build ui compent from json file.
-
+  \details It's depend Dtk::Widget::DSettingsWidgetFactory to auot build ui compent from json file.
   \sa Dtk::Widget::DSettingsWidgetFactory
   \sa Dtk::Core::DSettings
  */
@@ -83,7 +81,7 @@ DSettingsDialog::DSettingsDialog(QWidget *parent) :
     d->content->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     d->content->setAccessibleName("DSettingDialogContentWidget");
 
-    rightlayout->setMargin(0);
+    rightlayout->setContentsMargins(0, 0, 0, 0);
     rightlayout->addWidget(d->content);
 
     QHBoxLayout *bottomlayout = new QHBoxLayout;
@@ -123,13 +121,11 @@ DSettingsDialog::~DSettingsDialog()
 }
 
 /*!
-  \brief 获取当前对话框使用的控件构造工厂。
-  \brief Return the widget build factory of this dialog.
+  @~english
+  \brief get the factory of this dialog.
+  \details Every instance of DSettingDialog has it own widgetfactory.
+  \return Return the factory of this dialog.
 
-  每一个设置对话框都有自己的构造工厂实例，这些实例并不会共享数据。
-  Every instance of DSettingDialog has it own widgetfactory.
-
-  \return
  */
 DSettingsWidgetFactory *DSettingsDialog::widgetFactory() const
 {
@@ -144,9 +140,10 @@ bool DSettingsDialog::groupIsVisible(const QString &groupKey) const
 }
 
 /*!
-  \brief DSettingsDialog::setResetVisible 设置恢复默认设置按钮是否显示
-  \a visible true显示 false隐藏
-  \note 请在 updateSettings() 后调用
+  @~english
+  \brief DSettingsDialog::setResetVisible Set the default setting button to display
+  \param[in] visible true: show, false: hide
+  \note Please call after updateSettings ()
  */
 void DSettingsDialog::setResetVisible(bool visible)
 {
@@ -159,9 +156,10 @@ void DSettingsDialog::setResetVisible(bool visible)
 }
 
 /*!
-  \brief DSettingsDialog::scrollToGroup 使对话框跳转到指定的 group 项目
-  \a groupKey DSettings中 groupKeys 以及其子项 childGroups
-  \note 请在对话框 show 以后调用
+  @~english
+  \brief DSettingsDialog::scrollToGroup Turn the dialog to the specified group
+  \param[in] groupKey GroupKeys in DSettings and Childgroups
+  \note Please call after the dialog show()
  */
 void DSettingsDialog::scrollToGroup(const QString &groupKey)
 {
@@ -172,8 +170,9 @@ void DSettingsDialog::scrollToGroup(const QString &groupKey)
 }
 
 /*!
-  \brief DSettingsDialog::setIcon 设置标题栏的图标 QIcon
-  \a icon 设置的 Icon
+  @~english
+  \brief DSettingsDialog::setIcon Set the icon of the title bar
+  \param[in] icon the Icon Set
  */
 void DSettingsDialog::setIcon(const QIcon &icon)
 {
@@ -183,12 +182,9 @@ void DSettingsDialog::setIcon(const QIcon &icon)
 }
 
 /*!
-  \brief Create all widget for settings options.
-  \brief 根据settings数据来创建控件，该方法只能调用一次。
-  Warnning that you can only call the once.
-
-  \a settings 配置文件实例。
-  \a settings Dtk::Core::DSettings object from json
+  @~english
+  \brief Create all widget for settings options, that you can only call the once.
+  \param[in] settings Dtk::Core::DSettings object from json
  */
 void DSettingsDialog::updateSettings(Dtk::Core::DSettings *settings)
 {
@@ -197,14 +193,10 @@ void DSettingsDialog::updateSettings(Dtk::Core::DSettings *settings)
 }
 
 /*!
-  \brief 根据settings数据来创建控件，并使用translateContext来进行国际化，该方法只能调用一次.
+  @~english
   \brief Create all widget for settings options with translate context.
-
-  \a translateContext 国际化使用的上下文。
-  \a translateContext custom translate data for i18n.
-  \a settings 配置文件实例。
-  \a settings Dtk::Core::DSettings object from json
-
+  \param[in] translateContext custom translate data for i18n.
+  \param[in] settings Dtk::Core::DSettings object from json
   \sa DSettingsDialog::updateSettings(Dtk::Core::DSettings *settings)
  */
 void DSettingsDialog::updateSettings(const QByteArray &translateContext, Core::DSettings *settings)
