@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2016 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2016 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dsettingswidgetfactory.h"
 
@@ -148,10 +135,12 @@ static inline QString tr(const QByteArray &translateContext, const char *sourceT
   \return 生成的水平布局配置项控件
   \sa Dtk::Widget::DSettingsWidgetFactory::createTwoColumWidget(const QByteArray &translateContext, Dtk::Core::DSettingsOption *option, QWidget *rightWidget)
  */
+#if DTK_VERSION < DTK_VERSION_CHECK(6, 0, 0, 0)
 QWidget *DSettingsWidgetFactory::createTwoColumWidget(DTK_CORE_NAMESPACE::DSettingsOption *option, QWidget *rightWidget)
 {
     return createTwoColumWidget(QByteArray(), option, rightWidget);
 }
+#endif
 
 /*!
   \brief DSettingsWidgetFactory::createTwoColumWidget 返回一个水平布局的控件，
@@ -163,6 +152,7 @@ QWidget *DSettingsWidgetFactory::createTwoColumWidget(DTK_CORE_NAMESPACE::DSetti
   \return 生成的水平布局配置项控件
   \sa Dtk::Widget::DSettingsWidgetFactory::createTwoColumWidget(Dtk::Core::DSettingsOption *option, QWidget *rightWidget)
  */
+#if DTK_VERSION < DTK_VERSION_CHECK(6, 0, 0, 0)
 QWidget *DSettingsWidgetFactory::createTwoColumWidget(const QByteArray &translateContext, DTK_CORE_NAMESPACE::DSettingsOption *option, QWidget *rightWidget)
 {
     auto optionFrame = new QWidget;
@@ -184,6 +174,7 @@ QWidget *DSettingsWidgetFactory::createTwoColumWidget(const QByteArray &translat
 
     return  optionFrame;
 }
+#endif
 
 QPair<QWidget *, QWidget *> DSettingsWidgetFactory::createStandardItem(const QByteArray &translateContext, Core::DSettingsOption *option, QWidget *rightWidget)
 {
@@ -374,10 +365,18 @@ QPair<QWidget *, QWidget *> createComboBoxOptionHandle(QObject *opt)
         }
 
         rightWidget->clear();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         if (data.type() == QVariant::StringList) {
+#else
+        if (data.typeId() == QMetaType::Type::QStringList) {
+#endif
             initComboxList(data.toStringList());
         }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         if (data.type() == QVariant::Map) {
+#else
+        if (data.typeId() == QMetaType::Type::QVariantMap) {
+#endif
             initComboxMap(data.toMap());
         }
         rightWidget->update();
@@ -400,7 +399,7 @@ QPair<QWidget *, QWidget *> createButtonGroupOptionHandle(QObject *opt)
 
     auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
     auto items = option->data("items").toStringList();
-    for (const auto item : items) {
+    for (const auto &item : items) {
         auto btn = new DButtonBoxButton(item);
         btnList.append(btn);
     }
