@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2017 - 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: LGPL-3.0-or-later
 
@@ -7,6 +7,7 @@
 #include "dstyleoption.h"
 #include "dpalettehelper.h"
 #include "dstyle.h"
+#include "dsizemode.h"
 
 #include "dlistview.h"
 
@@ -97,10 +98,12 @@ static void loadDViewItemActionList(QDataStream &s, void *d)
 __attribute__((constructor))
 static void registerMetaType ()
 {
+    #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     // register DViewItemActionList's stream operator to support that QMetaType can using save and load function.
     QMetaType::registerStreamOperators(QMetaTypeId<DTK_WIDGET_NAMESPACE::ActionList>::qt_metatype_id(),
                                        saveDViewItemActionList,
                                        loadDViewItemActionList);
+    #endif
 }
 
 static DViewItemActionList qvariantToActionList(const QVariant &v)
@@ -194,6 +197,25 @@ public:
         return DStyle::viewItemSize(style, &item, Qt::DisplayRole);
     }
 
+    // get rect in AlignVCenter layout for text.
+    static QRect textAndTextActionsLayout(const QRect &textRect, const QStyle *style, const QStyleOptionViewItem &option, const QModelIndex &index)
+    {
+        QStyleOptionViewItem opt = option;
+        opt.displayAlignment |= Qt::AlignVCenter;
+        QSize size;
+
+        if (!opt.text.isEmpty())
+            size = DStyle::viewItemSize(style, &opt, Qt::DisplayRole);
+
+        for (const DViewItemAction *action : qvariantToActionList(index.data(Dtk::TextActionListRole))) {
+            const QSize &action_size = displayActionSize(action, style, opt);
+            size.setWidth(qMax(size.width(), action_size.width()));
+            size.setHeight(size.height() + action_size.height());
+        }
+
+        return QStyle::alignedRect(opt.direction , opt.displayAlignment, size, textRect);
+    }
+
     static QList<QRect> doActionsLayout(QRect base, const DViewItemActionList &list, Qt::Orientation orientation,
                                         Qt::LayoutDirection direction, const QSize &fallbackIconSize, QSize *bounding)
     {
@@ -245,13 +267,13 @@ public:
 
                 if (action->alignment().testFlag(Qt::AlignVCenter)) {
                     result_list << QStyle::alignedRect(direction, action->alignment(), size_list.at(i), center_rect);
-                    center_rect.setLeft(result_list.last().right() + spacing);
+                    center_rect.setLeft(result_list.last().right() + spacing + 1);
                 } else if (action->alignment().testFlag(Qt::AlignBottom)) {
                     result_list << QStyle::alignedRect(direction, action->alignment(), size_list.at(i), bottom_rect);
-                    bottom_rect.setLeft(result_list.last().right() + spacing);
+                    bottom_rect.setLeft(result_list.last().right() + spacing + 1);
                 } else {
                     result_list << QStyle::alignedRect(direction, action->alignment(), size_list.at(i), top_rect);
-                    top_rect.setLeft(result_list.last().right() + spacing);
+                    top_rect.setLeft(result_list.last().right() + spacing + 1);
                 }
 
                 if (bounding)
@@ -289,13 +311,13 @@ public:
 
                 if (action->alignment().testFlag(Qt::AlignHCenter)) {
                     result_list << QStyle::alignedRect(direction, action->alignment(), size_list.at(i), center_rect);
-                    center_rect.setTop(result_list.last().bottom() + spacing);
+                    center_rect.setTop(result_list.last().bottom() + spacing + 1);
                 } else if (action->alignment().testFlag(Qt::AlignRight)) {
                     result_list << QStyle::alignedRect(direction, action->alignment(), size_list.at(i), right_rect);
-                    right_rect.setTop(result_list.last().bottom() + spacing);
+                    right_rect.setTop(result_list.last().bottom() + spacing + 1);
                 } else {
                     result_list << QStyle::alignedRect(direction, action->alignment(), size_list.at(i), left_rect);
-                    left_rect.setTop(result_list.last().bottom() + spacing);
+                    left_rect.setTop(result_list.last().bottom() + spacing + 1);
                 }
 
                 if (bounding)
@@ -421,7 +443,6 @@ public:
         for (int i = 0; i < list.count(); ++i) {
             DViewItemAction *action = visiable_actionList.at(i);
             const QRect &rect = list.at(i).translated(origin);
-
             drawAction(pa, option, rect, action, spacing);
 
             if (action->isClickable()) {
@@ -639,6 +660,7 @@ DViewItemAction::DViewItemAction(Qt::Alignment alignment, const QSize &iconSize,
     d->clickable = clickable;
 }
 
+#if DTK_VERSION < DTK_VERSION_CHECK(6, 0, 0, 0)
 DViewItemAction::DViewItemAction(Qt::Alignment alignment, const QSize &iconSize,
                                  const QSize &maxSize, bool clickable, QObject *parent)
     : DViewItemAction(alignment, iconSize, maxSize, clickable)
@@ -647,6 +669,7 @@ DViewItemAction::DViewItemAction(Qt::Alignment alignment, const QSize &iconSize,
         qWarning() << "setting parent for a DViewItemAction object is no longer supported.";
     }
 }
+#endif
 
 /*!
   \brief 获取 DViewItemAction 放置的(水平)位置
@@ -1014,7 +1037,12 @@ void DStyledItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
             opt.displayAlignment &= ~Qt::AlignVCenter;
             opt.displayAlignment &= ~Qt::AlignBottom;
 
-            QRect bounding = DStyle::viewItemDrawText(style, painter, &opt, textRect);
+            QRect textRectbounding = d->textAndTextActionsLayout(textRect, style, opt, index);
+
+            QRect bounding(textRectbounding.topLeft(), QSize());
+            if (!opt.text.isEmpty()) {
+                bounding = DStyle::viewItemDrawText(style, painter, &opt, textRectbounding);
+            }
 
             // draw action text
             for (const DViewItemAction *action : text_action_list) {
@@ -1055,7 +1083,7 @@ void DStyledItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
             break;
         }
 
-        style->drawPrimitive(QStyle::PE_IndicatorViewItemCheck, &option, painter, widget);
+        style->drawPrimitive(QStyle::PE_IndicatorItemViewItemCheck, &option, painter, widget);
     }
 
     // reset rect for focus rect
@@ -1246,7 +1274,8 @@ void DStyledItemDelegate::setBackgroundType(DStyledItemDelegate::BackgroundType
         }
 
         int frame_margin = style->pixelMetric(static_cast<QStyle::PixelMetric>(DStyle::PM_FrameRadius));
-        d->margins += frame_margin;
+        int left_right_margin = style->pixelMetric(static_cast<QStyle::PixelMetric>(DStyle::PM_ContentsMargins));
+        d->margins += QMargins(left_right_margin, frame_margin, left_right_margin, frame_margin);
     }
 }
 
@@ -1355,7 +1384,8 @@ void DStyledItemDelegate::initStyleOption(QStyleOptionViewItem *option, const QM
         QPalette::ColorRole role = getViewItemColorRole(index, Dtk::ViewItemBackgroundRole);
 
         if (role != QPalette::NoRole) {
-            option->backgroundBrush = lv->palette().brush(role);
+            auto pa = option->widget ? option->widget->palette() : qApp->palette();
+            option->backgroundBrush = pa.brush(role);
         }
     }
 
@@ -1396,13 +1426,31 @@ bool DStyledItemDelegate::eventFilter(QObject *object, QEvent *event)
         break;
     }
     const auto view = qobject_cast<QAbstractItemView*>(parent());
+    if (event->type() == QEvent::StyleChange && view) {
+        D_D(DStyledItemDelegate);
+        do {
+            if (d->margins.isNull())
+                break;
+
+            int frame_margin = DStyle::pixelMetric(view->style(), DStyle::PM_FrameRadius);
+            int left_right_margin = DStyle::pixelMetric(view->style(), DStyle::PM_ContentsMargins);
+            d->margins = QMargins(left_right_margin, frame_margin, left_right_margin, frame_margin);
+
+            // relayout to calculate size.
+            view->doItemsLayout();
+        } while (false);
+    }
     if (view && object == view->viewport()) {
         static const QEvent::Type UpdateWidgetVisibleEvent(
                     static_cast<QEvent::Type>(QEvent::registerEventType()));
 
         if (event->type() == QEvent::Paint) {
             D_D(DStyledItemDelegate);
-            if (d->readyRecordVisibleWidgetOfCurrentFrame()) {
+            const QPaintEvent *pe = static_cast<QPaintEvent *>(event);
+            // We only hide widgets when updating all area, it maybe also to be paint when hover,
+            // and it's area is a specific part.
+            if (pe->rect() == view->viewport()->rect() &&
+                d->readyRecordVisibleWidgetOfCurrentFrame()) {
                 auto updateEvent = new QEvent(UpdateWidgetVisibleEvent);
                 qApp->postEvent(view->viewport(), updateEvent);
             }
