@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dswitchlineexpand.h"
 #include "dthememanager.h"
@@ -80,15 +67,12 @@ void DSwitchHeaderLine::mousePressEvent(QMouseEvent *)
 
   \a parent 指定了控件的父控件。
  */
-DSwitchLineExpand::DSwitchLineExpand(QWidget *parent) :
-    DBaseExpand(parent)
-{
+DSwitchLineExpand::DSwitchLineExpand(QWidget *parent) : DDrawer(parent) {
     m_headerLine = new DSwitchHeaderLine(this);
     m_headerLine->setExpand(expand());
     m_headerLine->setAccessibleName("DSwitchLineExpandHeaderLine");
-    connect(m_headerLine, &DSwitchHeaderLine::checkedChanged, [ = ](bool arg) {
-        DBaseExpand::setExpand(arg);
-    });
+    connect(m_headerLine, &DSwitchHeaderLine::checkedChanged,
+            [=](bool arg) { DDrawer::setExpand(arg); });
     setHeader(m_headerLine);
 }
 
@@ -130,14 +114,14 @@ DBaseLine *DSwitchLineExpand::header()
  */
 void DSwitchLineExpand::setHeader(QWidget *header)
 {
-    DBaseExpand::setHeader(header);
+    DDrawer::setHeader(header);
 }
 
 void DSwitchLineExpand::resizeEvent(QResizeEvent *e)
 {
     m_headerLine->setFixedWidth(e->size().width());
 
-    DBaseExpand::resizeEvent(e);
+    DDrawer::resizeEvent(e);
 }
 
 DWIDGET_END_NAMESPACE
