@@ -1,36 +1,21 @@
-/*
- * Copyright (C) 2016 ~ 2017 Deepin Technology Co., Ltd.
- *
- * Author:     Iceyer <me@iceyer.net>
- *
- * Maintainer: Iceyer <me@iceyer.net>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2016 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "dtoast.h"
 
+#if DTK_VERSION < DTK_VERSION_CHECK(6, 0, 0, 0)
+
 #include <DObjectPrivate>
+#include <DIcon>
 
 #include <QGraphicsOpacityEffect>
 #include <QPropertyAnimation>
 #include <QHBoxLayout>
 #include <QLabel>
-#include <QIcon>
 
 #include "dthememanager.h"
 #include "dgraphicsgloweffect.h"
-#include "dhidpihelper.h"
 
 DWIDGET_BEGIN_NAMESPACE
 
@@ -131,7 +116,7 @@ void DToast::setIcon(QString iconfile)
     D_D(DToast);
     d->icon = QIcon(iconfile);
     d->iconLabel->setVisible(true);
-    d->iconLabel->setPixmap(DHiDPIHelper::loadNxPixmap(iconfile));
+    d->iconLabel->setPixmap(DTK_GUI_NAMESPACE::DIcon::loadNxPixmap(iconfile));
 }
 
 /*!
@@ -259,3 +244,5 @@ void DToastPrivate::initUI()
 
 
 DWIDGET_END_NAMESPACE
+
+#endif
