@@ -1,27 +1,11 @@
-/*
- * Copyright (C) 2019 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     zccrs <zccrs@live.com>
- *
- * Maintainer: zccrs <zhangjide@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #ifndef DDRAWER_P_H
 #define DDRAWER_P_H
 
-#include "ddrawer.h"
+#include <DDrawer>
 #include "dframe_p.h"
 
 QT_BEGIN_NAMESPACE
@@ -41,6 +25,7 @@ public:
     ~DDrawerPrivate();
 
     void init();
+    void updateHeightDirect();
 
     QWidget *m_header = nullptr;
     QWidget *m_content = nullptr;
@@ -51,6 +36,7 @@ public:
     DHorizontalLine * m_hSeparator = nullptr;
     DHorizontalLine *m_bottom_separator = nullptr;
     QPropertyAnimation *m_animation = nullptr;
+    bool m_enableAnimation = false;
     bool m_expand = false;
     bool m_reservedPadding[7];
 
