@@ -1,7 +1,11 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #ifndef DFLOATINGWIDGET_P_H
 #define DFLOATINGWIDGET_P_H
 
-#include "dfloatingwidget.h"
+#include <DFloatingWidget>
 
 #include <DObjectPrivate>
 
