@@ -1,29 +1,12 @@
-﻿/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     chengyulong <chengyulong@uniontech.com>
-*
-* Maintainer: chengyulong <chengyulong@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #ifndef DPRINTPREVIEWWIDGET_P_H
 #define DPRINTPREVIEWWIDGET_P_H
 
 #include <dprintpreviewwidget.h>
-#include "private/dframe_p.h"
+#include "dframe_p.h"
 
 #include <DIconButton>
 
@@ -32,6 +15,7 @@
 #include <QWheelEvent>
 #include <QPicture>
 #include <qmath.h>
+#include <QBasicTimer>
 
 DWIDGET_BEGIN_NAMESPACE
 
@@ -165,6 +149,10 @@ public:
     {
         color = c;
     }
+    inline QColor getColor() const
+    {
+        return color;
+    }
     inline void setBoundingRect(const QRectF &rect)
     {
         qreal rotate = rotation();
@@ -264,6 +252,7 @@ public:
 
     void init();
     void populateScene();
+    void updatePreview();
     void generatePreview();
     void fitView();
     void print(bool printAsPicture = false);
@@ -280,7 +269,9 @@ public:
     int targetPage(int page);
     int index2page(int index);
     int page2index(int page);
-    D_DECL_DEPRECATED void impositionPages(); // 拼版
+#if DTK_VERSION < DTK_VERSION_CHECK(6, 0, 0, 0)
+    D_DECL_DEPRECATED void impositionPages();  // 拼版
+#endif
     int impositionPages(DPrintPreviewWidget::Imposition im); // 每页版数
     QImage generateWaterMarkImage() const;
     PrintOptions printerOptions();
@@ -319,8 +310,9 @@ public:
     DPrintPreviewWidget::Order order;
     qreal scale = 1.0;
     DPrintPreviewWidget::PageRange pageRangeMode = DPrintPreviewWidget::AllPage;
+#if DTK_VERSION < DTK_VERSION_CHECK(6, 0, 0, 0)
     D_DECL_DEPRECATED bool reviewChanged = true; // 预览页面是否发生改变
-
+#endif
     DPrinter *previewPrinter;
     RefreshMode refreshMode;
 
@@ -335,6 +327,7 @@ public:
 
     struct NumberUpData;
     NumberUpData *numberUpPrintData;
+    QBasicTimer updateTimer;
     Q_DECLARE_PUBLIC(DPrintPreviewWidget)
 };
 
@@ -416,7 +409,11 @@ struct DPrintPreviewWidgetPrivate::NumberUpData {
 
     QVector<QPointF> updatePositions(const qreal &scale)
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        QRectF pageRect = parent->previewPrinter->pageLayout().paintRectPixels(parent->previewPrinter->resolution());
+#else
         QRectF pageRect = parent->previewPrinter->pageRect();
+#endif
         QVector<QPointF> posList;
         QPointF startP(0, 0);
 
@@ -477,8 +474,11 @@ struct DPrintPreviewWidgetPrivate::NumberUpData {
     {
         if (waterList.isEmpty())
             return;
-
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        QRectF pageRect = parent->previewPrinter->pageLayout().paintRectPixels(parent->previewPrinter->resolution());
+#else
         QRectF pageRect = parent->previewPrinter->pageRect();
+#endif
         QMargins pageMargins = parent->previewPrinter->pageLayout().marginsPixels(parent->previewPrinter->resolution());
         const QVector<QPointF> &posList = updatePositions(scale);
 
