@@ -1,31 +1,15 @@
-/*
- * Copyright (C) 2011 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     wp <wangpeng_cm@deepin.com>
- *
- * Maintainer: wp <wangpeng_cm@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #ifndef DSEARCHEDIT_P_H
 #define DSEARCHEDIT_P_H
 
 #include "dlineedit_p.h"
-#include "dsearchedit.h"
+#include <DSearchEdit>
 
 #include <QLabel>
+#include <QPropertyAnimation>
 
 QT_BEGIN_NAMESPACE
 class QAudioInput;
@@ -54,6 +38,7 @@ public:
 
     QWidget *iconWidget;
     QLabel *label;
+    QPropertyAnimation *animation;
 
 #ifdef ENABLE_AI
     QAction *voiceAction = nullptr;
