@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2016 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2016 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "shortcutedit.h"
 
@@ -82,7 +69,11 @@ void ShortcutEdit::setShortCut(Qt::KeyboardModifiers modifier, Qt::Key key)
 
     d->keyStringList.clear();
     if (d->keyModifiers != Qt::NoModifier) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
         d->keyStringList << QKeySequence(d->keyModifiers).toString().split("+", QString::SkipEmptyParts);
+#else
+        d->keyStringList << QKeySequence(d->keyModifiers).toString().split("+", Qt::SkipEmptyParts);
+#endif
     }
     if (d->key != Qt::Key_unknown) {
         d->keyStringList << QKeySequence(d->key).toString();
@@ -106,7 +97,12 @@ void ShortcutEdit::paintEvent(QPaintEvent *)
 {
     Q_D(const ShortcutEdit);
     QPainter painter(this);
-    painter.setRenderHints(QPainter::Antialiasing | QPainter::HighQualityAntialiasing);
+
+    painter.setRenderHints(QPainter::Antialiasing
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+                           | QPainter::HighQualityAntialiasing
+#endif
+                            );
 
     if (d->keyStringList.isEmpty()) {
         // Draw tips
@@ -171,7 +167,13 @@ void ShortcutEdit::keyPressEvent(QKeyEvent *e)
         }
         d->keyStringList.clear();
         if (d->keyModifiers != Qt::NoModifier) {
-            d->keyStringList << QKeySequence(d->keyModifiers).toString().split("+", QString::SkipEmptyParts);
+            d->keyStringList << QKeySequence(d->keyModifiers).toString().split("+", 
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+            QString::SkipEmptyParts
+#else
+            Qt::SkipEmptyParts
+#endif
+            );
         }
         if (d->key != Qt::Key_unknown) {
             d->keyStringList << QKeySequence(d->key).toString();
