@@ -1,26 +1,11 @@
-/*
- * Copyright (C) 2021 ~ 2021 Deepin Technology Co., Ltd.
- *
- * Author:     Chen Bin <chenbin@uniontech.com>
- *
- * Maintainer: Chen Bin <chenbin@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2021 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include <gtest/gtest.h>
 #include <QTest>
 
+#include <QSignalSpy>
 #include <DIconButton>
 #include <DSuggestButton>
 #include <DLineEdit>
@@ -1648,3 +1633,61 @@ TEST_F(ut_DPrintPreviewDialog, themeTypeChanged)
 
     DGuiApplicationHelper::instance()->themeTypeChanged(DGuiApplicationHelper::DarkType);
 }
+
+TEST_F(ut_DPrintPreviewDialog, testPrivateUpdateSubControlSettings)
+{
+    test_dialog_d->waterMarkBtn->setChecked(true);
+    QSignalSpy spy(test_dialog_d->inclinatBox, &DSpinBox::editingFinished);
+    test_dialog_d->updateSubControlSettings(DPrintPreviewSettingInfo::PS_Watermark);
+    if (DPrintPreviewDialog::currentPlugin().isEmpty()) {
+        EXPECT_EQ(spy.count(), 0);
+    } else {
+        auto info = testPrintDialog->createDialogSettingInfo(DPrintPreviewSettingInfo::PS_Watermark);
+        if (info) {
+            EXPECT_EQ(spy.count(), 1);
+            delete info;
+        } else {
+            EXPECT_EQ(spy.count(), 0);
+        }
+    }
+}
+
+TEST_F(ut_DPrintPreviewDialog, createDialogSettingInfo)
+{
+    if (!DPrintPreviewDialog::currentPlugin().isEmpty()) {
+        return;
+    }
+
+    auto info = testPrintDialog->createDialogSettingInfo(DPrintPreviewSettingInfo::PS_Watermark);
+    ASSERT_TRUE(info);
+    EXPECT_EQ(info->type(), DPrintPreviewSettingInfo::PS_Watermark);
+    delete info;
+
+    info = testPrintDialog->createDialogSettingInfo(DPrintPreviewSettingInfo::PS_SettingsCount);
+    ASSERT_FALSE(info);
+}
+
+TEST_F(ut_DPrintPreviewDialog, updateDialogSettingInfo)
+{
+    if (!DPrintPreviewDialog::currentPlugin().isEmpty()) {
+        return;
+    }
+
+    test_dialog_d->waterMarkBtn->setChecked(true);
+    auto info = testPrintDialog->createDialogSettingInfo(DPrintPreviewSettingInfo::PS_Watermark);
+    auto watermarkInfo = dynamic_cast<DPrintPreviewWatermarkInfo *>(info);
+    ASSERT_TRUE(watermarkInfo);
+    EXPECT_EQ(watermarkInfo->opened, true);
+
+    watermarkInfo->opened = false;
+    bool newFlag = false;
+    testPrintDialog->updateDialogSettingInfo(watermarkInfo);
+    delete watermarkInfo;
+
+    info = testPrintDialog->createDialogSettingInfo(DPrintPreviewSettingInfo::PS_Watermark);
+    watermarkInfo = dynamic_cast<DPrintPreviewWatermarkInfo *>(info);
+    ASSERT_TRUE(watermarkInfo);
+    EXPECT_EQ(newFlag, watermarkInfo->opened);
+
+    delete watermarkInfo;
+}
